 /*******************************************************************************************************
  Nome
  7840_PLATRGS_GERA_HISTORICO_CARD.SQL

  Descrio
  GERAR HISTRICO PARA NO MOMENTO QUE O USUARIO ALTERAR UM CARDAPIO (TRANSFORM-LO EM ESPECFICO)
  O CAMPO ALTERADO IR REFLETIR NO RELATRIO DE HISTRICO DE ALTERACAO NO CARDPAIO

  Criao
  Alexis Tolentino de Moura

********************************************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE o.name = 'GERA_HISTORICO_CARD' and
                type = 'TR'                    and
                u.uid = o.uid                  and
                u.name = USER)

DROP TRIGGER GERA_HISTORICO_CARD
GO

CREATE TRIGGER GERA_HISTORICO_CARD
ON COMPCARD
FOR UPDATE

AS
   DECLARE @V_IDUTCARDPADR VARCHAR(01);
   DECLARE @V_CDGRUPOPER   VARCHAR(02);
   DECLARE @V_CDOPERADOR   VARCHAR(12);

   DECLARE @NEW_CDPRATO         VARCHAR(10);
   DECLARE @NEW_CDPRATOMAT      VARCHAR(10);
   DECLARE @NEW_CDFILAUXPRATMAT VARCHAR(04);
   DECLARE @NEW_IDPRATOESPE     VARCHAR(01);
   DECLARE @NEW_CDFILIAL        VARCHAR(04);
   DECLARE @NEW_NRCARDAPIO      VARCHAR(10);
   DECLARE @OLD_CDPRATO         VARCHAR(10);
   DECLARE @OLD_CDFILAUXPRAT    VARCHAR(04);
   DECLARE @OLD_CDPRATOMAT      VARCHAR(10);
   DECLARE @OLD_IDPRATOESPE     VARCHAR(01);
   DECLARE @V_CDOPERADOR_ATUAL  VARCHAR(12);

BEGIN
   DECLARE C_CURSOR CURSOR FOR
      SELECT
         INSERTED.CDPRATO         AS NEW_CDPRATO,
         INSERTED.CDPRATOMAT      AS NEW_CDPRATOMAT,
         INSERTED.CDFILAUXPRATMAT AS NEW_CDFILAUXPRATMAT,
         INSERTED.IDPRATOESPE     AS NEW_IDPRATOESPE,
         INSERTED.CDFILIAL        AS NEW_CDFILIAL,
         INSERTED.NRCARDAPIO      AS NEW_NRCARDAPIO,
         DELETED.CDPRATO          AS OLD_CDPRATO,
         DELETED.CDFILAUXPRAT     AS OLD_CDFILAUXPRAT,
         DELETED.CDPRATOMAT       AS OLD_CDPRATOMAT,
         DELETED.IDPRATOESPE      AS OLD_IDPRATOESPE
      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDFILIAL     = DELETED.CDFILIAL      AND
         INSERTED.NRCARDAPIO   = DELETED.NRCARDAPIO    AND
         INSERTED.NRSEQPRATCAR = DELETED.NRSEQPRATCAR;

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @NEW_CDPRATO,
                                 @NEW_CDPRATOMAT,
                                 @NEW_CDFILAUXPRATMAT,
                                 @NEW_IDPRATOESPE,
                                 @NEW_CDFILIAL,
                                 @NEW_NRCARDAPIO,
                                 @OLD_CDPRATO,
                                 @OLD_CDFILAUXPRAT,
                                 @OLD_CDPRATOMAT,
                                 @OLD_IDPRATOESPE;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF (@NEW_IDPRATOESPE = 'S') AND (@OLD_IDPRATOESPE <> 'S') AND (@OLD_CDPRATO <> @NEW_CDPRATO) BEGIN
         SELECT @V_IDUTCARDPADR = MAX(IDUTCARDPADR)
         FROM PARAMGERAL
         WHERE CDPARGERAL = '0001';

         IF (@V_IDUTCARDPADR = 'S') OR (@V_IDUTCARDPADR = 'D') BEGIN    /* CARDAPIO LIVRE NAO IRA GERAR HISTORICO */

            SELECT @V_CDGRUPOPER = MAX(CDGRUPOPER)
            FROM   AUTGRUPOP
            WHERE  IDAUTGRUPOP = 'LRCD';

            IF NOT (@V_CDGRUPOPER IS NULL) BEGIN                       /* O GRUPO COM AUTORIZACAO TEM QUE ESTA PARAMETRIZADO */

               SELECT @V_CDOPERADOR = MAX(CDOPERADOR)
               FROM
                  OPERGRUPOP
               WHERE
                  CDGRUPOPER = @V_CDGRUPOPER AND
                  CDOPERADOR = (SELECT MAX(SQ.DSREMOTEOPER)
                                FROM SQLWEBTUNNING SQ
                                WHERE SQ.NRAUDSID = @@SPID);

               IF (@V_CDOPERADOR IS NULL) BEGIN                    /* SE O OPERADOR NAO FIZER PARTE DO GRUPO PARAMETRIZADO */

                  SELECT @V_CDOPERADOR_ATUAL = MAX(SQ.DSREMOTEOPER)
                  FROM SQLWEBTUNNING SQ
                  WHERE SQ.NRAUDSID = @@SPID;

                  IF (@OLD_CDPRATOMAT IS NULL) BEGIN

                     UPDATE COMPCARD
                     SET CDPRATOMAT      = @OLD_CDPRATO,
                         CDFILAUXPRATMAT = @OLD_CDFILAUXPRAT,
                         CDOPERALTE = @V_CDOPERADOR_ATUAL,
                         DTCOMPCARDALT = GETDATE()
                     FROM INSERTED
                     WHERE COMPCARD.CDFILIAL     = INSERTED.CDFILIAL      AND
                           COMPCARD.NRCARDAPIO   = INSERTED.NRCARDAPIO    AND
                           COMPCARD.NRSEQPRATCAR = INSERTED.NRSEQPRATCAR  AND
                           COMPCARD.CDFILAUXPRAT = INSERTED.CDFILAUXPRAT  AND
                           COMPCARD.CDPRATO      = INSERTED.CDPRATO;

                  END;
               END;
            END;
         END;
      END;

      FETCH NEXT FROM C_CURSOR INTO @NEW_CDPRATO,
                                    @NEW_CDPRATOMAT,
                                    @NEW_CDFILAUXPRATMAT,
                                    @NEW_IDPRATOESPE,
                                    @NEW_CDFILIAL,
                                    @NEW_NRCARDAPIO,
                                    @OLD_CDPRATO,
                                    @OLD_CDFILAUXPRAT,
                                    @OLD_CDPRATOMAT,
                                    @OLD_IDPRATOESPE;

   END;

   CLOSE C_CURSOR;
   DEALLOCATE C_CURSOR;

END;
GO


-- VERSAO --
EXEC ATUVEROBJ 'GERA_HISTORICO_CARD','0.00.000';
GO