/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8170_CMPSTPO_NECESSIDADE_DE_COMPRAS.sql

Descrio:
Clculo das quantidades de produtos a serem comprados e gravao na tabela
TRABNECECOMP.
Tambm registra o LOG do clculo.

P_CDFILIAL    - Lista de filiais.
P_TCDFILIAL   - Todas as filiais.
P_CDGRUPFILI  - Agrupamento de filiais.
P_DTINICIAL   - Data inicial.
P_DTFINAL     - Data final.
P_CDPRODINI   - Cdigo de produto inicial.
P_CDPRODFIN   - Cdigo de produto final.
P_PEACRESCIMO - Percentual de acrscimo.
P_CDOPERADOR  - Cdigo do operador que solicitou o clculo.
P_DTHRCALCNC  - Data/hora do clculo.
P_IDQTDEZERO  - Indentificador que indica se os produtos com quantidade zero
                sero mantidos na tabela de trabalho.
P_NRNECECOMP  - Nmero sequencial a ser utilizado para gravao dos dados.

Criao:
23/02/1999 Yoris L. de Souza
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'NECESSIDADE_DE_COMPRAS'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE NECESSIDADE_DE_COMPRAS;
GO

CREATE PROCEDURE NECESSIDADE_DE_COMPRAS
   @P_CDFILIAL    VARCHAR(255),
   @P_TCDFILIAL   VARCHAR(1),
   @P_CDGRUPFILI  VARCHAR(10),
   @P_DTINICIAL   DATETIME,
   @P_DTFINAL     DATETIME,
   @P_CDPRODINI   VARCHAR(20),
   @P_CDPRODFIN   VARCHAR(20),
   @P_PEACRESCIMO NUMERIC,
   @P_CDOPERADOR  VARCHAR(12),
   @P_DTHRCALCNC  DATETIME,
   @P_IDQTDEZERO  VARCHAR(1),
   @P_NRNECECOMP  VARCHAR(10),
   @P_EXTRA       VARCHAR(1) = 'N',
   @P_CDSUBGRUPO  VARCHAR(10)= NULL,
   @P_CDGRUPPROD  VARCHAR(10)= NULL
AS
DECLARE @V_CDPRODUTO    VARCHAR(10);
DECLARE @V_CDARVPROD    VARCHAR(20);
DECLARE @V_QTPRACOMPRAR NUMERIC(15,5); /* Quantidade a ser comprada */
DECLARE @V_QTCONSPERIOD NUMERIC(15,5); /* Quantidade a ser consumida entre as entregas */
DECLARE @V_QTCONSANTECI NUMERIC(15,5); /* Quantidade da previso de consumo antecipada
                                   para entrega na data anterior devido ao
                                   limite de segurana */
DECLARE @V_QTASERENTREG NUMERIC(15,5); /* Quantidadeda previso de consumo a ser
                                   entregue na data de acordo com o limite de
                                   segurana */
DECLARE @V_QTJASOLICITA NUMERIC(15,5); /* Armazena a quantidade j solicitada at
                                   a data de entrega */
DECLARE @V_QTJASOLICPEXOL NUMERIC(15,5);
DECLARE @V_QTCONATEPREN NUMERIC(15,5); /* Quantidade a ser consumida da data de
                                   processamento at a primeira data de entrega */
DECLARE @V_QTESTONECCMP NUMERIC(15,5); /* Quantidade em estoque */
DECLARE @V_QTESTOQUEVND NUMERIC(15,5); /* Quantidade em estoque VND*/
DECLARE @V_CDPRODPREF   VARCHAR(10);
DECLARE @V_VRARREDCMP   NUMERIC(15,5);
DECLARE @V_VRFATOCONV   NUMERIC(10,4);
DECLARE @V_QTPRCNVCOMPR NUMERIC(10,3); /* Quantidade a comprar convertida na unidade do
                                   produto preferencial */
DECLARE @V_QTTEORNECCMP NUMERIC(15,5); /* Quantidade terica a ser comprada */
DECLARE @V_QTESTOUTILIZ NUMERIC(15,5); /* Quantidade do estoque que pode ser aproveitado,
                                   eliminando a necessidade de nova compra */
DECLARE @V_QTESTOQATUAL NUMERIC(15,5); /* Quantidade em estoque */
DECLARE @V_QTORIGNECCMP NUMERIC(15,5); /* Quantidade antes de ser convertida para a
                                   unidade do produto preferencial */
DECLARE @V_QTESTAFPEND  NUMERIC(15,5); --Adriano GR
       /* Quantidade de AF Pendente anterior a primeira entregue, que far parte
          do estoque inicial para abater o consumo at a primeira entrega mais
         o consumo antecipado */
DECLARE @V_QTESTAFPEXOL NUMERIC(15,5);
DECLARE @V_QTESTAFPANT  NUMERIC(15,5); --Adriano na GR
     /* Entrega de AF Pendente - AF's baixadas via NF na data de processamento
        com entrega programada anteriormente  data de processamento
        Far parte do estoque inicial para abater do consumo do perodo + consumo antecipado */
DECLARE @V_QTESTAFPDEP  NUMERIC(15,5); --Adriano na GR
    /* Entrega de AF Antecipada - AF's baixadas via NF na data de processamento
       com entrega programada posteriormente  data de processamento
       Far parte do estoque inicial para abater do consumo do perodo + consumo antecipado */

DECLARE @V_IDUTPRODPREF VARCHAR(1);

DECLARE @V_IDUTILLOTE   VARCHAR(1);

DECLARE @V_RETIRDATA    NUMERIC;
DECLARE @V_ENTRADATA    NUMERIC;
DECLARE @V_DTPROCESS    DATETIME;
DECLARE @V_DTAUX        DATETIME;

DECLARE @V_DTPRIUTIPROD DATETIME;

DECLARE @V_CDPRODINI    VARCHAR(40);
DECLARE @V_CDPRODFIN    VARCHAR(40);

DECLARE @V_IDPRIVEZPROD VARCHAR(1);
DECLARE @V_IDEVOLESTONC VARCHAR(1);

DECLARE @V_DTPRIMENTREG DATETIME;

DECLARE @V_IDQTDEZERO   VARCHAR(1);

DECLARE @V_NRDIASEG     NUMERIC;
DECLARE @V_NRDIASEGANT  NUMERIC;

DECLARE @V_DTMAXENT     DATETIME;

DECLARE @V_VALRESTO     NUMERIC(15,5);
DECLARE @V_VALRBRUT     NUMERIC(15,5);

DECLARE @V_CDPERIENTR   VARCHAR(2);
DECLARE @V_DTPREVCONS   DATETIME;
DECLARE @V_DTENTREGA    DATETIME;
DECLARE @V_DTENTREGA_1  DATETIME;
DECLARE @V_DTANTPROXENT DATETIME;

DECLARE @V_DELTRAB_NRNECECOMP   VARCHAR(10);
DECLARE @V_DELTRAB_CDPRODNECCMP VARCHAR(10);
DECLARE @V_DELTRAB_DTENTRNECCMP DATETIME;

DECLARE @V_DTINICIAL   DATETIME;
DECLARE @V_CONTAUXI    NUMERIC;

DECLARE @V_IDSISDOS     VARCHAR(1);  --Adriano GR
DECLARE @V_IDMARCNECCMP VARCHAR(1); --Adriano na GR

DECLARE @V_QTESTNEGATIVCALC  NUMERIC(15,5); --Adriano na GR
DECLARE @V_QTESTNEGATIVIMPR  NUMERIC(15,5);
DECLARE @V_IDESTNEGATIVO VARCHAR(1);  --Adriano na GR
DECLARE @V_IDPRIENTRFP   VARCHAR(1);  --Adriano na GR
DECLARE @V_QTAFANTPRIENT NUMERIC(15,5); --Adriano na GR

DECLARE @V_QTDIAESTOQ   INTEGER; --Adriano na GR /* Utilizada para pegar a posio de estoque atual(0) ou o estoque inicial do dia(1) */

DECLARE @V_IDUTILDTPROC  VARCHAR(1);
DECLARE @V_CDFILCENTCMP  VARCHAR(4);
DECLARE @V_QTESTOSEGU NUMERIC(15,5);
DECLARE @V_NRLIMISEGCAD VARCHAR(3);
DECLARE @VCUR_FILIAL VARCHAR(4);
DECLARE @V_IDENTFORPERI VARCHAR(1);
DECLARE @V_COUNT     INT;
DECLARE @V_INAT      INT;
DECLARE @V_PRODFILI  INT;
DECLARE @V_APENAS_CONSUMO INT;
DECLARE @V_IDESTOQUE      VARCHAR(1);
DECLARE @V_CDFILIAL       VARCHAR(4);
DECLARE @V_IDFILCENTPME   VARCHAR(1);
DECLARE @V_IDCONSAFNECCMP VARCHAR(1);
DECLARE @V_EXTRA          VARCHAR(1);

DECLARE @V_IDMAPDISTALMOX            VARCHAR(1);
DECLARE @V_PREVISAOVND_CDFILIAL      VARCHAR(4);
DECLARE @V_PREVISAOVND_CDLOJA        VARCHAR(10);
DECLARE @V_PREVISAOVND_CDPRODUTO     VARCHAR(10);
DECLARE @V_PREVISAOVND_CDALMOXARIFE  VARCHAR(6);
DECLARE @V_PREVISAOVND_CDLOCALESTOQ  VARCHAR(6);
DECLARE @V_PREVISAOVND_QTPREVCONS    NUMERIC(15,5);
DECLARE @V_CDFILIOPELOG              VARCHAR(4);
DECLARE @V_QTAFFUTURA                NUMERIC(15,5);

DECLARE @V_PERFILPROD_DNUTIL       VARCHAR(1); -- Parmetro utiliza dia no util da tabela PERFILPROD (tem precedncia ao PERIENTR)
DECLARE @V_PERFILPROD_SITENTR      VARCHAR(1); -- Parmetro que define se atrasa (A) ou adianta (D) a entrega do produto
DECLARE @V_DTATRASA                DATE;
DECLARE @V_DTTESTE                 DATE;
DECLARE @V_DTATRASA2               DATE;
DECLARE @V_DTANTAUX                DATE;
DECLARE @V_DTTEMP                  DATE;
DECLARE @V_QTDTEMP                 FLOAT;--NUMERIC;
DECLARE @V_CONTADOR                INT;
DECLARE @V_TESTE                   INT;--NUMERIC;
DECLARE @V_COMPARA                 INT;
DECLARE @V_CONTROLE                INT;
DECLARE @V_CONTTEMP                INT;
DECLARE @V_CONTWHILE               VARCHAR(1);
DECLARE @V_IDCSSOLAFFORAPERICMP    VARCHAR(1);
DECLARE @V_IDCONSANTECPENDNECC     VARCHAR(1);
DECLARE @V_DTANTPROXENT_1          DATE;
DECLARE @V_UTILIZOU_JASOLI         CHAR(1);
DECLARE @V_IDDESCONSILIMCALCMP     CHAR(1);
DECLARE @V_QTSOLIPROD              FLOAT;
DECLARE @V_QTPROGENTAF             FLOAT;
DECLARE @V_NRSEQCMPGER             VARCHAR(10);
DECLARE @V_NFSTATUSLI              FLOAT;
DECLARE @V_DTMAXENTREGA_ADD1       DATE;
DECLARE @V_DTMAXENTREGA            DATE;
DECLARE @V_QTJASOLICITADAFP        NUMERIC(15,5);
DECLARE @V_QTJASOLICITADA1         NUMERIC(15,5);
DECLARE @V_QTJASOLICITADA2         NUMERIC(15,5);
DECLARE @V_IDCONSSOLRELACAFNEC     CHAR(1);
DECLARE @V_QTPROGENTAF1            NUMERIC(15,5);
DECLARE @V_QTEFETENTRAF            NUMERIC(15,5);


BEGIN
   IF @P_EXTRA IS NULL BEGIN
      SET @V_EXTRA = 'N';
   END
   ELSE BEGIN
      SET @V_EXTRA = @P_EXTRA;
   END;
   SELECT --Adriano GR
      @V_IDSISDOS     = MAX(IDSISDOS), --Adriano GR
      @V_IDUTILDTPROC = MAX(IDUTILDTPROC)
   FROM
      PARAMGERAL;

   IF @V_IDSISDOS = '3' BEGIN  --Adriano GR
      SET @V_QTDIAESTOQ = 0;
   END
   ELSE BEGIN
      SET @V_QTDIAESTOQ = 1;
   END;

   IF @P_CDPRODINI > @P_CDPRODFIN
   BEGIN
      SET @V_CDPRODINI = (SUBSTRING(@P_CDPRODINI+(REPLICATE('Z', 20)), 1, 20));
      SET @V_CDPRODFIN = @P_CDPRODFIN;
   END
   ELSE
   BEGIN
      SET @V_CDPRODFIN = (SUBSTRING(@P_CDPRODFIN+(REPLICATE('Z', 20)), 1, 20));
      SET @V_CDPRODINI = @P_CDPRODINI;
   END;

   SET @V_IDQTDEZERO = @P_IDQTDEZERO;

   DECLARE CUR_FILIAL CURSOR FOR
      (SELECT
          FILIAL.CDFILIAL
       FROM
          FILIAL
       WHERE
          ((CHARINDEX(FILIAL.CDFILIAL, @P_CDFILIAL) > 0) OR (@P_TCDFILIAL = 'T')) AND
          (@P_CDGRUPFILI IS NULL)
       UNION
       SELECT
          FILGRUPFILI.CDFILIAL
       FROM
          FILGRUPFILI
       WHERE
          ((CHARINDEX(FILGRUPFILI.CDFILIAL, @P_CDFILIAL) > 0) OR (@P_TCDFILIAL = 'T')) AND
          (FILGRUPFILI.CDGRUPFILI = @P_CDGRUPFILI))
   OPEN CUR_FILIAL;
   FETCH NEXT FROM CUR_FILIAL INTO @VCUR_FILIAL;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      SET @V_COUNT = 0;
      SET @V_CDFILCENTCMP = '';
      SET @V_IDESTOQUE    = '';
      SET @V_CDFILIAL      = '';
      SELECT
         @V_CDFILIAL  = MAX(CDFILIAL),
         @V_IDESTOQUE = ISNULL(MAX(IDSCONESTNEC), 'N'),
         @V_IDMAPDISTALMOX = ISNULL(MAX(IDMAPDISTALMOX), 'N')
      FROM
         PARCMPSUP
      WHERE
         CDFILIAL = @VCUR_FILIAL;

      SELECT
         @V_IDCSSOLAFFORAPERICMP = ISNULL(MAX(P.IDCSSOLAFFORAPERICMP), 'N'),
         @V_IDCONSANTECPENDNECC  = ISNULL(MAX(P.IDCONSANTECPENDNECC), 'N'),
         @V_IDDESCONSILIMCALCMP  = ISNULL(MAX(P.IDDESCONSILIMCALCMP), 'N'),
         @V_IDCONSSOLRELACAFNEC  = ISNULL(MAX(P.IDCONSSOLRELACAFNEC), 'N')
      FROM
         PARASUPRI P INNER JOIN FILIAL F ON P.CDFILIAL = ISNULL(F.CDFILCENTCMP, F.CDFILIAL)
      WHERE F.CDFILIAL = @VCUR_FILIAL;

      IF @V_CDFILIAL IS NOT NULL BEGIN
         SELECT
            @V_CDFILCENTCMP = ISNULL(MAX(FILIAL.CDFILCENTCMP), MAX(FILIAL.CDFILIAL)),
            @V_IDFILCENTPME = ISNULL(MAX(FILIAL.IDFILCENTPME), 'N')
         FROM
            FILIAL
         WHERE
            FILIAL.CDFILIAL = @VCUR_FILIAL

         IF NOT((ISNULL(@P_TCDFILIAL, ' ') = 'T') AND (@V_IDFILCENTPME = 'S'))  BEGIN
            SET @V_COUNT = 0;
            SELECT
               @V_COUNT          = COUNT(*),
               @V_IDEVOLESTONC   = ISNULL(MAX(IDEVOLESTONC), 'N'),
               @V_IDCONSAFNECCMP = ISNULL(MAX(IDCONSAFNECCMP), 'N'),
               @V_IDCONSANTECPENDNECC = ISNULL(MAX(IDCONSANTECPENDNECC), 'N')
            FROM
               PARASUPRI
            WHERE
               CDFILIAL = @V_CDFILCENTCMP
         END;
      END;
      IF @V_COUNT > 0 BEGIN
         /* - Verifica a data de processamento para a filial informada ------------ */
         IF @V_IDUTILDTPROC <> 'S'
         BEGIN
            SET @V_DTPROCESS = CONVERT(DATETIME, CONVERT(VARCHAR, GETDATE(), 103), 103);
            SELECT
               @V_IDUTILLOTE = ISNULL(MAX(IDUTILLOTE), 'N')
            FROM
               PARAMFILIAL
            WHERE
               (CDFILIAL = @VCUR_FILIAL);
         END
         ELSE
         BEGIN
            SELECT
               @V_DTPROCESS  = ISNULL(MAX(DTPROCESSA),CONVERT(DATETIME, CONVERT(VARCHAR, GETDATE(), 103), 103)),
               @V_IDUTILLOTE = ISNULL(MAX(IDUTILLOTE), 'N')
            FROM
               PARAMFILIAL
            WHERE
               (CDFILIAL = @VCUR_FILIAL);
         END;

         DECLARE C_PREV CURSOR FOR
            (SELECT
             PREVCONGER.CDPRODUTO,
             PREVCONGER.CDARVPROD
             FROM
               (SELECT
                   ESTOSEGU.CDFILIAL,
                   ESTOSEGU.CDPRODESTO AS CDPRODUTO,
                   PRODUTO.CDARVPROD
                FROM
                   PRODUTO,
                   ESTOSEGU
                WHERE
                   ESTOSEGU.CDFILIAL = @VCUR_FILIAL AND
                   PRODUTO.CDPRODUTO = ESTOSEGU.CDPRODESTO AND
                   PRODUTO.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  PREVCONS.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONS
                WHERE
                  PREVCONS.CDFILIAL    = @VCUR_FILIAL  AND
                  CONVERT(DATETIME, CONVERT(VARCHAR, PREVCONS.DTPREVCONS, 103), 103) >= @V_DTPROCESS AND
                  PREVCONS.CDPRODUTO = PROD_PREV.CDPRODUTO AND
                  PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  ITPREVCOMP.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  ITPREVCOMP
                WHERE
                  ITPREVCOMP.CDFILIAL    = @VCUR_FILIAL  AND
                  CONVERT(DATETIME, CONVERT(VARCHAR, ITPREVCOMP.DTENTPRECOMP, 103), 103) >= @V_DTPROCESS AND
                  ITPREVCOMP.CDPRODUTO = PROD_PREV.CDPRODUTO    AND
                  ITPREVCOMP.IDSTITPRCOMP = 'A'                 AND
                  PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  PREVCOMPRA.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCOMPRA
                WHERE
                  PREVCOMPRA.CDFILIAL    = @VCUR_FILIAL  AND
                  CONVERT(DATETIME, CONVERT(VARCHAR, PREVCOMPRA.DTPREVCOMP, 103), 103) >= @V_DTPROCESS AND
                  PREVCOMPRA.CDPRODUTO = PROD_PREV.CDPRODUTO AND
                  PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  PC.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC
                WHERE PC.CDFILIAL      = @VCUR_FILIAL
                  AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                  AND PC.CDPRODUTO = PROD_PREV.CDPRODUTO
                  AND PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN
                  AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                  AND NOT EXISTS (SELECT 1
                                  FROM ROTFABLOCAL
                                  WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                    AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                UNION ALL

                SELECT
                  PC.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC,
                  ROTFABRICA ROT
                WHERE ROT.CDSUBPRODUTO = PROD_PREV.CDPRODUTO
                  AND ROT.CDPRODUTO = PC.CDPRODUTO
                  AND PC.CDFILIAL      = @VCUR_FILIAL
                  AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                  AND PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN
                  AND NOT EXISTS (SELECT 1
                                  FROM ROTFABLOCAL
                                  WHERE ROTFABLOCAL.CDFILIAL = PC.CDFILIAL
                                    AND ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO)

                UNION ALL

                SELECT
                  PC.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC,
                  ROTFABLOCAL ROT
                WHERE ROT.CDSUBPRODLOC = PROD_PREV.CDPRODUTO
                  AND ROT.CDPRODUTO    = PC.CDPRODUTO
                  AND ROT.CDFILIAL     = PC.CDFILIAL
                  AND PC.CDFILIAL      = @VCUR_FILIAL
                  AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                  AND PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  PREVCONSVMN.CDFILIALCLIE AS CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSVMN
                WHERE
                  PREVCONSVMN.CDFILIALCLIE  = @VCUR_FILIAL  AND
                  CONVERT(DATETIME, CONVERT(VARCHAR, PREVCONSVMN.DTPREVENDVMN, 103), 103)  >= @V_DTPROCESS AND
                  PREVCONSVMN.CDPRODUTO     = PROD_PREV.CDPRODUTO AND
                  PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT DISTINCT
                   @VCUR_FILIAL AS CDFILIAL,
                   PR.CDPRODESTO AS CDPRODUTO,
                   PROD_PREV.CDARVPROD
                FROM
                   ITEMSOLI,
                   PRODUTO PR,
                   PRODUTO PROD_PREV,
                   FILIAL
                WHERE
                   FILIAL.CDFILCENTPME = @VCUR_FILIAL AND
                   CONVERT(DATETIME, CONVERT(VARCHAR, ITEMSOLI.DTPROGENTR, 103), 103)  >= @V_DTPROCESS      AND
                   ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'       AND
                   ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'       AND
                   ITEMSOLI.CDPRODUTO = PR.CDPRODUTO AND
                   PR.CDPRODESTO = PROD_PREV.CDPRODUTO AND
                   ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL     AND
                  (PR.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN) AND
                   ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                    CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                 FROM
                                                                    CMPCENTENDIR,
                                                                    PRODUTO PI,
                                                                    PRODUTO PC
                                                                 WHERE
                                                                    CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                    CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                    ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                    PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                UNION ALL

                SELECT
                  PREVCONSPME.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPME
                WHERE
                  PREVCONSPME.CDFILIAL    = @VCUR_FILIAL  AND
                  CONVERT(DATETIME, CONVERT(VARCHAR, PREVCONSPME.DTPREVCONPME, 103), 103)  >= @V_DTPROCESS      AND
                  PREVCONSPME.CDPRODUTO = PROD_PREV.CDPRODUTO AND
                  PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONS PC,
                  FILINECE FI,
                  FILIAL
                WHERE
                  (FI.CDFILINECCMP  = PC.CDFILIAL                         ) AND
                  FI.CDFILIAL = FILIAL.CDFILIAL     AND
                  ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                  (FI.IDSOLIPREV    = 'P'                                 ) AND
                  (FI.CDFILIAL      = @VCUR_FILIAL                        ) AND
                  (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPREVCONS, 103), 103)    >= @V_DTPROCESS) AND
                  (PC.CDPRODUTO     = PROD_PREV.CDPRODUTO                 ) AND
                  (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCOMPRA PC,
                  FILINECE FI,
                  FILIAL
                WHERE
                  (FI.CDFILINECCMP  = PC.CDFILIAL)                          AND
                   FI.CDFILIAL = FILIAL.CDFILIAL     AND
                  ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                  (FI.IDSOLIPREV    = 'P')                                  AND
                  (FI.CDFILIAL      = @VCUR_FILIAL)                         AND
                  (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPREVCOMP, 103), 103) >= @V_DTPROCESS)                     AND
                  (PC.CDPRODUTO     = PROD_PREV.CDPRODUTO)                  AND
                  (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC,
                  FILINECE FI,
                  FILIAL
                WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                  AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                  AND (FI.CDFILINECCMP  = PC.CDFILIAL)
                  AND (FI.IDSOLIPREV    = 'P')
                  AND (FI.CDFILIAL      = @VCUR_FILIAL)
                  AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS  )
                  AND (PC.CDPRODUTO     = PROD_PREV.CDPRODUTO)
                  AND (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)
                  AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                  AND NOT EXISTS (SELECT 1
                                  FROM ROTFABLOCAL
                                  WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                    AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC,
                  ROTFABRICA ROT,
                  FILINECE FI,
                  FILIAL
                WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                  AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                  AND (FI.CDFILINECCMP  = PC.CDFILIAL)
                  AND (FI.IDSOLIPREV    = 'P')
                  AND (FI.CDFILIAL      = @VCUR_FILIAL)
                  AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS  )
                  AND (ROT.CDSUBPRODUTO = PROD_PREV.CDPRODUTO)
                  AND (ROT.CDPRODUTO    = PC.CDPRODUTO)
                  AND (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)
                  AND NOT EXISTS (SELECT 1
                                  FROM ROTFABLOCAL
                                  WHERE ROTFABLOCAL.CDFILIAL = PC.CDFILIAL
                                    AND ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSPDVDIA PC,
                  ROTFABLOCAL ROT,
                  FILINECE FI,
                  FILIAL
                WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                  AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                  AND (FI.CDFILINECCMP  = PC.CDFILIAL)
                  AND (FI.IDSOLIPREV    = 'P')
                  AND (FI.CDFILIAL      = @VCUR_FILIAL)
                  AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS  )
                  AND (ROT.CDSUBPRODLOC = PROD_PREV.CDPRODUTO)
                  AND (ROT.CDPRODUTO    = PC.CDPRODUTO)
                  AND (ROT.CDFILIAL     = PC.CDFILIAL)
                  AND (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PROD_PREV.CDPRODESTO AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  PRODUTO PROD_PREV,
                  PREVCONSVMN PC,
                  FILINECE FI,
                  FILIAL
                WHERE
                  (FI.CDFILINECCMP  = PC.CDFILIALCLIE)                      AND
                  FI.CDFILIAL = FILIAL.CDFILIAL     AND
                  ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                  (FI.IDSOLIPREV    = 'P'            )                      AND
                  (FI.CDFILIAL      = @VCUR_FILIAL)                  AND
                  (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPREVENDVMN, 103), 103)  >= @V_DTPROCESS    ) AND
                  (PC.CDPRODUTO     = PROD_PREV.CDPRODUTO)                  AND
                  (PROD_PREV.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN)

                UNION ALL

                SELECT
                  FI.CDFILIAL,
                  PR.CDPRODESTO  AS CDPRODUTO,
                  PROD_PREV.CDARVPROD
                FROM
                  ITEMSOLI IT,
                  PRODUTO PR,
                  PRODUTO PROD_PREV,
                  FILINECE FI,
                  FILIAL
                WHERE
                  (FI.CDFILIAL     = @VCUR_FILIAL)            AND
                  FI.CDFILIAL = FILIAL.CDFILIAL     AND
                  ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                  (IT.DTPROGENTR   >= @V_DTPROCESS)                   AND
                  (PR.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN) AND
                  (FI.CDFILINECCMP = IT.CDFILSOLI)                   AND
                  (FI.IDSOLIPREV  <> 'P')                            AND
                  (IT.CDPRODUTO    = PR.CDPRODUTO) AND
                  (PR.CDPRODESTO = PROD_PREV.CDPRODUTO) ) PREVCONGER
            WHERE ((@P_CDSUBGRUPO IS NULL)  OR
                  (EXISTS(SELECT 1
                            FROM PRSUBGRPROD
                           WHERE PRSUBGRPROD.CDGRUPPROD  = @P_CDGRUPPROD
                             AND CHARINDEX(PRSUBGRPROD.CDSUBGRPROD, @P_CDSUBGRUPO) > 0
                             AND PRSUBGRPROD.CDPRODUTO   = PREVCONGER.CDPRODUTO)))
            GROUP BY
               PREVCONGER.CDPRODUTO,
               PREVCONGER.CDARVPROD);
         OPEN C_PREV;
         FETCH NEXT FROM C_PREV INTO @V_CDPRODUTO, @V_CDARVPROD;
         WHILE (@@FETCH_STATUS = 0)
         BEGIN
            SET @V_PRODFILI = 0;
            SELECT
               @V_PRODFILI = COUNT(*)
            FROM
               PRODFILI
            WHERE
               @VCUR_FILIAL         = PRODFILI.CDFILIAL   AND
               @V_CDPRODUTO         = PRODFILI.CDPRODUTO  AND
               ISNULL(PRODFILI.IDPRODATIV,'A') = 'A';
            IF @V_PRODFILI > 0 BEGIN
               /* Verifica se houve retirada para considerar a previso de consumo na data
                  de processamento */
               IF @V_IDSISDOS = '3' BEGIN --Adriano GR

                 SET @V_ENTRADATA = 0;
                 SET @V_RETIRDATA = 0;
               END
               ELSE BEGIN
                  SET @V_RETIRDATA = 0;
                  SELECT
                     @V_RETIRDATA = COUNT(*)
                  FROM
                     ITLANCTOEST
                  WHERE
                     (ITLANCTOEST.CDFILIMOVI = @VCUR_FILIAL)  AND
                     (ITLANCTOEST.DTLANCMOVI = @V_DTPROCESS) AND
                     (ITLANCTOEST.CDPRODMOVI = @V_CDPRODUTO) AND
                     (ITLANCTOEST.IDTIPOMOVI = '3');

            /*      @V_RETIRDATA := 0; DISCUTIR */

                  /* Verifica se houve entrada para considerar como estoque entregue */

                  SET @V_ENTRADATA = 0;
                  SELECT
                     @V_ENTRADATA = COUNT(*)
                  FROM
                     ITLANCTOEST
                  WHERE
                     (ITLANCTOEST.CDFILIMOVI = @VCUR_FILIAL)  AND
                     (ITLANCTOEST.DTLANCMOVI = @V_DTPROCESS) AND
                     (ITLANCTOEST.CDPRODMOVI = @V_CDPRODUTO) AND
                     (ITLANCTOEST.IDTIPOMOVI = '2');
               END;

            /*   @V_ENTRADATA := 0;  DISCUTIR */

               SET @V_IDPRIVEZPROD     = 'S';
               SET @V_IDPRIENTRFP      = 'S';
               SET @V_QTESTONECCMP     = 0;
               SET @V_QTESTNEGATIVCALC = 0;
               SET @V_QTESTNEGATIVIMPR = 0;
               SET @V_DTPRIMENTREG = NULL;
               DECLARE C_PREV_DATA CURSOR FOR
                  SELECT
                     CALECOMP.DTENTREGA,
                     CALECOMP.DTANTPROXENT,
                     CALECOMP.CDPERIENTR,
                     'N' AS IDENTFORPERI /* Identificador de AF fora da periodicidade do produto */
                  FROM
                     PERFILPROD,
                     CALECOMP,
                     PRODUTO
                  WHERE
                     (PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO) AND
                     (PERFILPROD.CDFILIAL  = @VCUR_FILIAL)  AND
                     (PRODUTO.CDARVPROD = (SELECT
                                              MAX(B.CDARVPROD)
                                           FROM
                                              PERFILPROD A,
                                              PRODUTO B
                                           WHERE
                                              (A.CDPRODUTO = B.CDPRODUTO) AND
                                              (A.CDFILIAL = @VCUR_FILIAL) AND
                                              (CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1))) AND
                     (CALECOMP.CDFILIAL = @VCUR_FILIAL) AND
                     (CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR) AND
                     (CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND @P_DTFINAL)
                  UNION ALL
                  SELECT DISTINCT ITEMAUTF.DTPROGENTAF AS DTENTREGA, CONVERT(DATETIME, 0, 103) AS DTANTPROXENT,
                                  '  ' AS CDPERIENTR,  'S' AS IDENTFORPERI
                    FROM PRODUTO P, AUTOFORNE, ITEMAUTF
                   WHERE ITEMAUTF.CDFILDEST     = @VCUR_FILIAL
                     AND @V_IDCSSOLAFFORAPERICMP = 'S'
                     AND AUTOFORNE.IDAFFORALIM  = 'N'
                     AND AUTOFORNE.CDFILDEST    = ITEMAUTF.CDFILDEST
                     AND AUTOFORNE.CDFILLANC    = ITEMAUTF.CDFILLANC
                     AND AUTOFORNE.NRAUTOFORN   = ITEMAUTF.NRAUTOFORN
                     AND ITEMAUTF.CDPRODUTO     = P.CDPRODUTO
                     AND P.CDPRODESTO           = @V_CDPRODUTO
                     AND AUTOFORNE.IDSITUATUAAF IS NULL
                     AND (ITEMAUTF.IDBAIXITMAF  IS NULL OR ITEMAUTF.IDBAIXITMAF = '1')
                     AND ITEMAUTF.DTPROGENTAF   BETWEEN @V_DTPROCESS AND @P_DTFINAL
                     AND ISNULL(AUTOFORNE.IDAFEXPIRADA, 'N') = 'N'
                     AND ITEMAUTF.DTPROGENTAF NOT IN (SELECT CALECOMP.DTENTREGA
                                                      FROM PERFILPROD, CALECOMP, PRODUTO
                                                      WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                                        AND PERFILPROD.CDFILIAL  = ITEMAUTF.CDFILDEST
                                                        AND CALECOMP.CDFILIAL    = ITEMAUTF.CDFILDEST
                                                        AND CALECOMP.CDPERIENTR  = PERFILPROD.CDPERIENTR
                                                        AND CALECOMP.DTENTREGA   BETWEEN @V_DTPROCESS AND @P_DTFINAL
                                                        AND PRODUTO.CDARVPROD    = (SELECT
																						MAX(B.CDARVPROD)
																					FROM
																						PERFILPROD A,
																						PRODUTO B
																					WHERE
																						(A.CDPRODUTO = B.CDPRODUTO) AND
																						(A.CDFILIAL = @VCUR_FILIAL) AND
																						(CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)))
                  ORDER BY
                     1;
               OPEN C_PREV_DATA;
               FETCH NEXT FROM C_PREV_DATA INTO @V_DTENTREGA, @V_DTANTPROXENT, @V_CDPERIENTR, @V_IDENTFORPERI;
               WHILE (@@FETCH_STATUS = 0)
               BEGIN
                  SELECT @V_DTMAXENTREGA      = MAX(DTENTREGA) ,
                         @V_DTMAXENTREGA_ADD1 = MAX(DTENTREGA)+1
                     FROM CALECOMP
                     WHERE CDFILIAL   = @VCUR_FILIAL
                       AND CDPERIENTR = @V_CDPERIENTR
                       AND DTENTREGA  < @V_DTENTREGA;
                  SELECT
                     @V_QTCONSPERIOD = ISNULL(SUM(QTPRODCONS),0)
                  FROM
                    (SELECT
                       PREVCONS.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONS,
                       PRODUTO
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                       PREVCONS.DTPREVCONS >= @V_DTPROCESS AND
                       PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO  = @V_CDPRODUTO  AND
                       (PREVCONS.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PREVCONS.DTPREVCONS BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       ITPREVCOMP.QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       ITPREVCOMP,
                       PRODUTO
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       ITPREVCOMP.CDFILIAL    = @VCUR_FILIAL  AND
                       ITPREVCOMP.DTENTPRECOMP >= @V_DTPROCESS AND
                       ITPREVCOMP.CDPRODUTO = PRODUTO.CDPRODUTO    AND
                       PRODUTO.CDPRODESTO  = @V_CDPRODUTO  AND
                       ITPREVCOMP.IDSTITPRCOMP = 'A'                 AND
                       (ITPREVCOMP.DTENTPRECOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (ITPREVCOMP.DTENTPRECOMP BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                        ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                        ITEMSOLI,
                        PRODUTO,
                        FILIAL
                     WHERE
                      @V_IDENTFORPERI        = 'N'          AND
                      PRODUTO.CDPRODESTO     = @V_CDPRODUTO AND
                      FILIAL.CDFILCENTPME    = @VCUR_FILIAL AND
                      ITEMSOLI.DTPROGENTR   >= @V_DTPROCESS AND
                      ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'   AND
                      ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'   AND
                      PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO  AND
                      ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL     AND
                      (ITEMSOLI.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                      (ITEMSOLI.DTPROGENTR BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT) AND
                       ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                        CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                     FROM
                                                                        CMPCENTENDIR,
                                                                        PRODUTO PI,
                                                                        PRODUTO PC
                                                                     WHERE
                                                                        CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                        CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                        ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                        PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                     UNION ALL

                     SELECT
                       PREVCONSPME.QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPME,
                       PRODUTO
                     WHERE
                        @V_IDENTFORPERI        = 'N'          AND
                        PREVCONSPME.CDFILIAL      = @VCUR_FILIAL  AND
                        PREVCONSPME.DTPREVCONPME  >= @V_DTPROCESS AND
                        PREVCONSPME.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO        = @V_CDPRODUTO  AND
                        (PREVCONSPME.DTPREVCONPME <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PREVCONSPME.DTPREVCONPME BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCOMPRA,
                       PRODUTO
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                       PREVCOMPRA.DTPREVCOMP >= @V_DTPROCESS AND
                       PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                       (PREVCOMPRA.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PREVCOMPRA.DTPREVCOMP BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       PRODUTO
                     WHERE @V_IDENTFORPERI = 'N'
                       AND PC.CDFILIAL     = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                       AND PC.CDPRODUTO    = PRODUTO.CDPRODUTO
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)
                       AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                       AND NOT EXISTS (SELECT 1
                                       FROM ROTFABLOCAL
                                       WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                         AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                     UNION ALL

                     SELECT
                       ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       ROTFABRICA ROT,
                       PRODUTO
                     WHERE @V_IDENTFORPERI    = 'N'
                       AND PC.CDFILIAL        = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                       AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                       AND ROT.CDPRODUTO      = PC.CDPRODUTO
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)
                       AND NOT EXISTS (SELECT 1
                                       FROM ROTFABLOCAL
                                       WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                         AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                     UNION ALL

                     SELECT
                       ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       ROTFABLOCAL ROT,
                       PRODUTO
                     WHERE @V_IDENTFORPERI    = 'N'
                       AND PC.CDFILIAL        = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                       AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                       AND ROT.CDPRODUTO      = PC.CDPRODUTO
                       AND ROT.CDFILIAL       = PC.CDFILIAL
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSVMN,
                       PRODUTO
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       PREVCONSVMN.CDFILIALCLIE  = @VCUR_FILIAL   AND
                       PREVCONSVMN.DTPREVENDVMN >= @V_DTPROCESS AND
                       PREVCONSVMN.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                       (PREVCONSVMN.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PREVCONSVMN.DTPREVENDVMN BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONS PC,
                       FILINECE FI,
                       PRODUTO,
                       FILIAL
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       FI.CDFILIAL = FILIAL.CDFILIAL     AND
                       ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                       FI.CDFILINECCMP = PC.CDFILIAL  AND
                       FI.IDSOLIPREV   = 'P'          AND
                       FI.CDFILIAL     = @VCUR_FILIAL   AND
                       PC.DTPREVCONS   >= @V_DTPROCESS AND
                       PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                       (PC.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PC.DTPREVCONS BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       PC.QTPRODCOMP AS QTPRODCONS
                     FROM
                       PREVCOMPRA PC,
                       FILINECE FI,
                       FILIAL
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       FI.CDFILIAL = FILIAL.CDFILIAL     AND
                       ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                       FI.CDFILINECCMP  = PC.CDFILIAL  AND
                       FI.IDSOLIPREV    = 'P'          AND
                       FI.CDFILIAL      = @VCUR_FILIAL   AND
                       PC.DTPREVCOMP    >= @V_DTPROCESS AND
                       PC.CDPRODUTO     = @V_CDPRODUTO AND
                       (PC.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PC.DTPREVCOMP BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       FILINECE FI,
                       PRODUTO,
                       FILIAL
                     WHERE @V_IDENTFORPERI = 'N'
                       AND FI.CDFILIAL = FILIAL.CDFILIAL
                       AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                       AND FI.CDFILINECCMP  = PC.CDFILIAL
                       AND FI.IDSOLIPREV    = 'P'
                       AND FI.CDFILIAL      = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                       AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)
                       AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                       AND NOT EXISTS (SELECT 1
                                       FROM ROTFABLOCAL
                                       WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                         AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                     UNION ALL

                     SELECT
                       ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       ROTFABRICA ROT,
                       FILINECE FI,
                       PRODUTO,
                       FILIAL
                     WHERE @V_IDENTFORPERI = 'N'
                       AND FI.CDFILIAL = FILIAL.CDFILIAL
                       AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                       AND FI.CDFILINECCMP  = PC.CDFILIAL
                       AND FI.IDSOLIPREV    = 'P'
                       AND FI.CDFILIAL      = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                       AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                       AND ROT.CDPRODUTO      = PC.CDPRODUTO
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)
                       AND NOT EXISTS (SELECT 1
                                       FROM ROTFABLOCAL
                                       WHERE ROTFABLOCAL.CDFILIAL = PC.CDFILIAL
                                         AND ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO)

                     UNION ALL

                     SELECT
                       ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPDVDIA PC,
                       ROTFABLOCAL ROT,
                       FILINECE FI,
                       PRODUTO,
                       FILIAL
                     WHERE @V_IDENTFORPERI = 'N'
                       AND FI.CDFILIAL = FILIAL.CDFILIAL
                       AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                       AND FI.CDFILINECCMP  = PC.CDFILIAL
                       AND FI.IDSOLIPREV    = 'P'
                       AND FI.CDFILIAL      = @VCUR_FILIAL
                       AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                       AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                       AND ROT.CDFILIAL       = PC.CDFILIAL
                       AND ROT.CDPRODUTO      = PC.CDPRODUTO
                       AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                       AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSVMN PC,
                       FILINECE FI,
                       PRODUTO,
                       FILIAL
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       FI.CDFILIAL = FILIAL.CDFILIAL     AND
                       ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                       FI.CDFILINECCMP  = PC.CDFILIALCLIE  AND
                       FI.IDSOLIPREV    = 'P'              AND
                       FI.CDFILIAL      = @VCUR_FILIAL       AND
                       PC.DTPREVENDVMN  >= @V_DTPROCESS     AND
                       PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                       (PC.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PC.DTPREVENDVMN BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)

                     UNION ALL

                     SELECT
                       IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                     FROM
                       ITEMSOLI IT,
                       PRODUTO PR,
                       FILINECE FI,
                       FILIAL
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       FI.CDFILIAL = FILIAL.CDFILIAL     AND
                       ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                       FI.CDFILIAL     = @VCUR_FILIAL   AND
                       IT.DTPROGENTR   >= @V_DTPROCESS AND
                       IT.CDPRODUTO    = PR.CDPRODUTO AND
                       PR.CDPRODESTO   = @V_CDPRODUTO AND
                       FI.CDFILINECCMP = IT.CDFILSOLI AND
                       FI.IDSOLIPREV  <> 'P'          AND
                       (IT.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (IT.DTPROGENTR BETWEEN @V_DTENTREGA AND @V_DTANTPROXENT)) PREVCONGER;

                  IF @V_QTCONSPERIOD IS NULL
                  BEGIN
                     SET @V_QTCONSPERIOD = 0;
                  END
                  ELSE
                  BEGIN
                     SET @V_QTCONSPERIOD = @V_QTCONSPERIOD  * (1 + (@P_PEACRESCIMO/100));
                  END;

                  EXEC LIMISEGU_CONS_DNUT @VCUR_FILIAL, @V_CDARVPROD, @V_DTENTREGA, @V_CDPERIENTR, @P_NRLIMISEGU = @V_NRDIASEG OUTPUT, @P_NRLIMISEGCAD = @V_NRLIMISEGCAD OUTPUT;
                  EXEC LIMISEGU @VCUR_FILIAL, @V_CDARVPROD, @V_DTANTPROXENT, @V_CDPERIENTR, @P_NRLIMISEGU = @V_NRDIASEGANT OUTPUT, @P_NRLIMISEGCAD = @V_NRLIMISEGCAD OUTPUT;

                  SET @V_QTCONSANTECI = 0;
                     
                  SELECT @V_PERFILPROD_DNUTIL  = ISNULL(IDDNULIMSEGPR, 'N'), 
                         @V_PERFILPROD_SITENTR = ISNULL(IDSITUENTREGA, 'D')
                    FROM PERFILPROD PFP, PRODUTO PRO
                   WHERE PFP.CDPRODUTO = PRO.CDPRODUTO
                     AND PFP.CDFILIAL = @VCUR_FILIAL
                     AND PRO.CDARVPROD = ( SELECT MAX(CDARVPROD)
                                             FROM PRODUTO PR, PERFILPROD PF
                                            WHERE PR.CDPRODUTO = PF.CDPRODUTO
                                              AND PF.CDFILIAL = @VCUR_FILIAL
                                              AND (CHARINDEX(PR.CDARVPROD, @V_CDARVPROD) = 1));

                  /* Entra quando estiver marcado o parmetro 'Verificadia no til na apurao da necessidade de compras utilizando limite de segurana
                     e quando estiver marcado o parmetro "Atrasa Entrega" */
                  IF @V_PERFILPROD_DNUTIL = 'S' AND @V_PERFILPROD_SITENTR = 'A'
                  BEGIN 
                    --INICIO      
                    SET @V_CONTWHILE = 'T';
                    SET @V_QTASERENTREG = 0; -- QTD A SER ENTREGUE
                    SET @V_QTCONSANTECI = 0; -- QTD ANTECIPADO
                    SET @V_DTATRASA2  = NULL;
                    
                    IF (CONVERT(INT, @V_NRLIMISEGCAD)) < (DATEDIFF(DAY, @V_DTENTREGA, @V_DTANTPROXENT))
                    BEGIN
                      SET @V_CONTROLE = (DATEDIFF(DAY, @V_DTENTREGA, @V_DTANTPROXENT));
                    END
                    ELSE 
                    BEGIN
                      SET @V_CONTROLE = (CONVERT(INT, @V_NRLIMISEGCAD));
                    END;   
                       
                    SET @V_CONTADOR = 0;
                    SET @V_CONTTEMP = 0;
                    SET @V_DTTEMP = NULL;
                       
                    WHILE (@V_CONTADOR <= @V_CONTROLE)
                    BEGIN
                    
                       IF @V_NRDIASEG > 0
                       BEGIN
                          -- BUSCA O CONSUMO ANTECIPADO (ATRASA).
                          -- @V_QTCONSANTECI
                          SET @V_QTDTEMP = 0;
                          SET @V_DTTESTE = DATEADD(DAY, (@V_CONTADOR - 1), @V_DTENTREGA);
                          SET @V_COMPARA = 0;
                          SET @V_DTATRASA2 = NULL;
                          
                          IF (@V_DTTEMP IS NULL)
                          BEGIN
                             IF @V_CONTADOR <= (CONVERT(INT, @V_NRLIMISEGCAD))
                             BEGIN
                                SET @V_DTANTAUX = NULL;

                                SELECT @V_DTANTAUX = DTENTREGA
                                FROM CALECOMP
                                WHERE CDFILIAL   = @P_CDFILIAL
                                  AND DTANTPROXENT = (@V_DTTESTE)
                                  AND CDPERIENTR = @V_CDPERIENTR;

                                SET @V_TESTE = 0;
                                SELECT @V_TESTE = 1
                                FROM CALECOMP
                                WHERE CHARINDEX(CALECOMP.CDFILIAL, @P_CDFILIAL) <> 0
                                  AND (CALECOMP.DTENTREGA = (@V_DTANTAUX))
                                  AND CALECOMP.CDPERIENTR = @V_CDPERIENTR;

                                IF (@V_TESTE = 1)
                                BEGIN
                                   IF (DATEDIFF(DAY, @V_DTANTAUX, @V_DTTESTE)) < 1
                                   BEGIN
                                      SET @V_DTATRASA2 = @V_DTTESTE;
                                   END
                                   ELSE
                                   BEGIN
                                      IF (DATEDIFF(DAY, @V_DTANTAUX, @V_DTTESTE)) >= CONVERT(INT, @V_NRLIMISEGCAD)
                                      BEGIN
                                         SET @V_DTATRASA2 = @V_DTANTAUX;
                                         SET @V_DTTEMP = DATEADD(DAY, 1, @V_DTANTAUX);
                                      END
                                      ELSE
                                      BEGIN
                                         SET @V_DTATRASA2 = NULL;
                                         SET @V_DTTEMP = DATEADD(DAY, -1, @V_DTTESTE);
                                         IF @V_DTENTREGA <= @V_DTANTAUX
                                         BEGIN
                                            SET @V_DTATRASA2 = @V_DTTESTE;
                                            SET @V_DTTEMP = NULL;
                                         END;
                                      END;
                                   END;
                                END
                                ELSE
                                BEGIN
                                   SET @V_DTATRASA2 = NULL;
                                END;
                             END;
                          END
                          ELSE
                          BEGIN
                             SET @V_COMPARA = 0;
                             SET @V_TESTE = 0;

                             SELECT @V_TESTE = 1
                             FROM CALECOMP
                             WHERE CHARINDEX(CALECOMP.CDFILIAL, @P_CDFILIAL) <> 0
                               AND (CALECOMP.DTENTREGA = (DATEADD(DAY, @V_CONTTEMP, @V_DTTEMP)))
                               AND CALECOMP.CDPERIENTR = @V_CDPERIENTR;

                             IF (@V_TESTE = 1)
                             BEGIN
                                SET @V_DTATRASA2 = DATEADD(DAY, @V_CONTTEMP, @V_DTTEMP);
                             END
                             ELSE
                             BEGIN
                                SET @V_DTATRASA2 = NULL;
                             END;
                             
                             SET @V_CONTTEMP = @V_CONTTEMP + 1;
                          END;
                          
                          /* Busca a quantidade consumida antecipadamente entre a data de entrega e o limite de segurana */
                          SELECT
                             @V_QTDTEMP = ISNULL(SUM(PREVCONGER.QTPRODCONS),0)
                          FROM
                             (SELECT
                               QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONS,
                               PRODUTO
                             WHERE
                               PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                               PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                               PRODUTO.CDPRODESTO  = @V_CDPRODUTO AND
                               PREVCONS.DTPREVCONS = @V_DTATRASA2 AND
                               PREVCONS.DTPREVCONS > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                                ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                                ITEMSOLI,
                                PRODUTO,
                                FILIAL
                             WHERE
                                PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                                FILIAL.CDFILCENTPME = @VCUR_FILIAL     AND
                                ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N' AND
                                ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S' AND
                                PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO AND
                                PRODUTO.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN AND
                                ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL  AND
                                ITEMSOLI.DTPROGENTR = @V_DTATRASA2     AND
                                ITEMSOLI.DTPROGENTR > (DATEADD(DAY, -1, @V_DTENTREGA)) AND
                                ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                                 CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                              FROM
                                                                                 CMPCENTENDIR,
                                                                                 PRODUTO PI,
                                                                                 PRODUTO PC
                                                                              WHERE
                                                                                 CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                                 CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                                 ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                                 PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                             UNION ALL

                             SELECT
                               QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPME,
                               PRODUTO
                             WHERE
                               PREVCONSPME.CDFILIAL     = @VCUR_FILIAL AND
                               PREVCONSPME.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                               PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                               PREVCONSPME.DTPREVCONPME = @V_DTATRASA2 AND
                               PREVCONSPME.DTPREVCONPME > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               ITPREVCOMP,
                               PRODUTO
                             WHERE
                               ITPREVCOMP.CDFILIAL     = @VCUR_FILIAL  AND
                               ITPREVCOMP.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                               PRODUTO.CDPRODESTO      = @V_CDPRODUTO AND
                               ITPREVCOMP.IDSTITPRCOMP = 'A' AND
                               ITPREVCOMP.DTENTPRECOMP = @V_DTATRASA2 AND
                               ITPREVCOMP.DTENTPRECOMP > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCOMPRA,
                               PRODUTO
                             WHERE
                               PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                               PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                               PRODUTO.CDPRODESTO    = @V_CDPRODUTO AND
                               PREVCOMPRA.DTPREVCOMP = @V_DTATRASA2 AND
                               PREVCOMPRA.DTPREVCOMP > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               PRODUTO
                             WHERE PC.CDPRODUTO = PRODUTO.CDPRODUTO
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))
                               AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                               AND NOT EXISTS (SELECT 1
                                               FROM ROTFABLOCAL
                                               WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                                 AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                             UNION ALL

                             SELECT
                               ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               ROTFABRICA ROT,
                               PRODUTO
                             WHERE PC.CDFILIAL        = @VCUR_FILIAL
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))
                               AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                               AND ROT.CDPRODUTO      = PC.CDPRODUTO
                               AND NOT EXISTS (SELECT 1
                                               FROM ROTFABLOCAL
                                               WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                                 AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                             UNION ALL

                             SELECT
                               ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               ROTFABLOCAL ROT,
                               PRODUTO
                             WHERE PC.CDFILIAL        = @VCUR_FILIAL
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))
                               AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                               AND ROT.CDFILIAL       = PC.CDFILIAL
                               AND ROT.CDPRODUTO      = PC.CDPRODUTO

                             UNION ALL

                             SELECT
                               QTSOLCONVMN * PRODUTO.VRFATOCONV  AS QTPRODCONS
                             FROM
                               PREVCONSVMN,
                               PRODUTO
                             WHERE
                               PREVCONSVMN.CDFILIALCLIE = @VCUR_FILIAL   AND
                               PREVCONSVMN.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                               PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                               PREVCONSVMN.DTPREVENDVMN = @V_DTATRASA2 AND 
                               PREVCONSVMN.DTPREVENDVMN > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONS PC,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE
                               FI.CDFILIAL = FILIAL.CDFILIAL          AND
                               ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                               FI.CDFILINECCMP = PC.CDFILIAL          AND
                               FI.IDSOLIPREV   = 'P'                  AND
                               FI.CDFILIAL     = @VCUR_FILIAL         AND
                               PC.CDPRODUTO    = PRODUTO.CDPRODUTO    AND
                               PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                               PC.DTPREVCONS = @V_DTATRASA2           AND
                               PC.DTPREVCONS > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               PC.QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCOMPRA PC,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE
                               FI.CDFILIAL = FILIAL.CDFILIAL          AND
                               ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                               FI.CDFILINECCMP  = PC.CDFILIAL         AND
                               FI.IDSOLIPREV    = 'P'                 AND
                               FI.CDFILIAL      = @VCUR_FILIAL        AND
                               PC.CDPRODUTO     = PRODUTO.CDPRODUTO   AND
                               PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                               PC.DTPREVCOMP = @V_DTATRASA2           AND
                               PC.DTPREVCOMP > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                               AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                               AND FI.CDFILINECCMP  = PC.CDFILIAL
                               AND FI.IDSOLIPREV    = 'P'
                               AND FI.CDFILIAL      = @VCUR_FILIAL
                               AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))
                               AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                               AND NOT EXISTS (SELECT 1
                                               FROM ROTFABLOCAL
                                               WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                                 AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                             UNION ALL

                             SELECT
                               ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               ROTFABRICA ROT,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                               AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                               AND FI.CDFILINECCMP  = PC.CDFILIAL
                               AND FI.IDSOLIPREV    = 'P'
                               AND FI.CDFILIAL      = @VCUR_FILIAL
                               AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                               AND ROT.CDPRODUTO    = PC.CDPRODUTO
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))
                               AND NOT EXISTS (SELECT 1
                                               FROM ROTFABLOCAL
                                               WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                                 AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                             UNION ALL

                             SELECT
                               ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSPDVDIA PC,
                               ROTFABLOCAL ROT,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                               AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                               AND FI.CDFILINECCMP  = PC.CDFILIAL
                               AND FI.IDSOLIPREV    = 'P'
                               AND FI.CDFILIAL      = @VCUR_FILIAL
                               AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                               AND ROT.CDPRODUTO    = PC.CDPRODUTO
                               AND ROT.CDFILIAL     = PC.CDFILIAL
                               AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA2
                               AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                             FROM
                               PREVCONSVMN PC,
                               FILINECE FI,
                               PRODUTO,
                               FILIAL
                             WHERE
                               FI.CDFILIAL = FILIAL.CDFILIAL          AND
                               ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                               FI.CDFILINECCMP  = PC.CDFILIALCLIE     AND
                               FI.IDSOLIPREV    = 'P'                 AND
                               FI.CDFILIAL      = @VCUR_FILIAL        AND
                               PC.CDPRODUTO     = PRODUTO.CDPRODUTO   AND
                               PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                               PC.DTPREVENDVMN = @V_DTATRASA2         AND
                               PC.DTPREVENDVMN > (DATEADD(DAY, -1, @V_DTENTREGA))

                             UNION ALL

                             SELECT
                               IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                             FROM
                               ITEMSOLI IT,
                               PRODUTO PR,
                               FILINECE FI,
                               FILIAL
                             WHERE
                               FI.CDFILIAL = FILIAL.CDFILIAL  AND
                               ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                               FI.CDFILIAL     = @VCUR_FILIAL AND
                               IT.CDPRODUTO    = PR.CDPRODUTO AND
                               PR.CDPRODESTO   = @V_CDPRODUTO AND
                               IT.CDPRODUTO    = PR.CDPRODUTO AND
                               FI.CDFILINECCMP = IT.CDFILSOLI AND
                               FI.IDSOLIPREV  <> 'P'          AND
                               IT.DTPROGENTR   = @V_DTATRASA2 AND
                               IT.DTPROGENTR > (DATEADD(DAY, -1, @V_DTENTREGA))
                             ) PREVCONGER;
                             
                          SET @V_QTCONSANTECI = @V_QTCONSANTECI + @V_QTDTEMP;
                       END;

                       IF @V_QTCONSANTECI IS NULL
                       BEGIN
                          SET @V_QTCONSANTECI = 0;
                       END
                       ELSE
                       BEGIN
                          SET @V_QTCONSANTECI = @V_QTCONSANTECI * (1 + (@P_PEACRESCIMO/100));
                       END;
                       
                    --MEIO
                    
                       SET @V_COMPARA    = 0;
                       SET @V_DTTESTE    = @V_DTENTREGA + @V_CONTADOR;
                       SET @V_DTATRASA   = NULL;

                       WHILE (@V_CONTWHILE = 'T')
                       BEGIN
                            SET @V_TESTE = 0;
                           SELECT @V_TESTE = 1
                           FROM CALECOMP
                           WHERE CHARINDEX(CALECOMP.CDFILIAL, @P_CDFILIAL) <> 0
                             AND (CALECOMP.DTENTREGA = DATEADD(DAY,-(CONVERT(INT, @V_NRLIMISEGCAD) - @V_COMPARA), @V_DTTESTE))
                             AND CALECOMP.CDPERIENTR = @V_CDPERIENTR;

                           IF (@V_TESTE = 1)
                           BEGIN
                              IF (@V_COMPARA >= 0)
                              BEGIN
                                 IF (DATEADD(DAY,-(CONVERT(INT, @V_NRLIMISEGCAD) - @V_COMPARA), @V_DTTESTE) = @V_DTENTREGA)
                                 BEGIN
                                    SET @V_DTATRASA = @V_DTTESTE;
                                 END;
                              END
                              ELSE
                              BEGIN
                                 SET @V_DTATRASA = @V_DTTESTE;
                              END;
                              BREAK;
                           END;

                           IF (@V_COMPARA >= (CONVERT(INT, @V_NRLIMISEGCAD)))
                           BEGIN
                              IF @V_COMPARA > 0
                              BEGIN
                                 SET @V_COMPARA = -@V_COMPARA;
                              END;
                              SET @V_COMPARA = @V_COMPARA - 1;
                           END
                           ELSE
                           BEGIN
                              IF @V_COMPARA >= 0
                              BEGIN
                                 SET @V_COMPARA = @V_COMPARA + 1;
                              END
                              ELSE
                              BEGIN
                                 SET @V_COMPARA = @V_COMPARA - 1;
                              END;
                           --FINAL WHILE DEFINE A DATA
                        END;
                       END;
                       /*QUANTIDADE A SER ENTREGUE*/

                       SELECT
                          @V_QTDTEMP = ISNULL(SUM(QTPRODCONS),0)
                       FROM
                       (SELECT
                           QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONS,
                           PRODUTO
                         WHERE
                           PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                           PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                           PRODUTO.CDPRODESTO  = @V_CDPRODUTO AND
                           (PREVCONS.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PREVCONS.DTPREVCONS = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           ITPREVCOMP,
                           PRODUTO
                         WHERE
                           ITPREVCOMP.CDFILIAL = @VCUR_FILIAL  AND
                           ITPREVCOMP.CDPRODUTO = PRODUTO.CDPRODUTO AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                           ITPREVCOMP.IDSTITPRCOMP = 'A' AND
                           (ITPREVCOMP.DTENTPRECOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (ITPREVCOMP.DTENTPRECOMP = @V_DTATRASA)

                         UNION ALL

                         SELECT
                            ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                            ITEMSOLI,
                            PRODUTO,
                            FILIAL
                         WHERE
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (ITEMSOLI.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (ITEMSOLI.DTPROGENTR = @V_DTATRASA) AND
                            FILIAL.CDFILCENTPME = @VCUR_FILIAL AND
                            ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N' AND
                            ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S' AND
                            PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO AND
                            ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL  AND
                            ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                             CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                          FROM
                                                                             CMPCENTENDIR,
                                                                             PRODUTO PI,
                                                                             PRODUTO PC
                                                                          WHERE
                                                                             CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                             CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                             ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                             PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                        UNION ALL

                        SELECT
                          QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPME,
                          PRODUTO
                        WHERE
                          PREVCONSPME.CDFILIAL     = @VCUR_FILIAL  AND
                          PREVCONSPME.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                          (PREVCONSPME.DTPREVCONPME <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PREVCONSPME.DTPREVCONPME = @V_DTATRASA)


                         UNION ALL

                         SELECT
                           QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCOMPRA,
                           PRODUTO
                         WHERE
                           PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                           PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                           (PREVCOMPRA.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PREVCOMPRA.DTPREVCOMP = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           PRODUTO
                         WHERE PC.CDFILIAL     = @VCUR_FILIAL
                           AND PC.CDPRODUTO    = PRODUTO.CDPRODUTO
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)
                           AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                           AND NOT EXISTS (SELECT 1
                                           FROM ROTFABLOCAL
                                           WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                             AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                         UNION ALL

                         SELECT
                           ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           ROTFABRICA ROT,
                           PRODUTO
                         WHERE PC.CDFILIAL     = @VCUR_FILIAL
                           AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                           AND ROT.CDPRODUTO    = PC.CDPRODUTO
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)
                           AND NOT EXISTS (SELECT 1
                                           FROM ROTFABLOCAL
                                           WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                             AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                         UNION ALL

                         SELECT
                           ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           ROTFABLOCAL ROT,
                           PRODUTO
                         WHERE PC.CDFILIAL        = @VCUR_FILIAL
                           AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                           AND ROT.CDPRODUTO      = PC.CDPRODUTO
                           AND ROT.CDFILIAL       = PC.CDFILIAL
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSVMN,
                           PRODUTO
                         WHERE
                           PREVCONSVMN.CDFILIALCLIE  = @VCUR_FILIAL   AND
                           PREVCONSVMN.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                           (PREVCONSVMN.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PREVCONSVMN.DTPREVENDVMN = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONS PC,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE
                           FI.CDFILIAL = FILIAL.CDFILIAL          AND
                           ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                           FI.CDFILINECCMP = PC.CDFILIAL          AND
                           FI.IDSOLIPREV   = 'P'                  AND
                           FI.CDFILIAL     = @VCUR_FILIAL         AND
                           PC.CDPRODUTO    = PRODUTO.CDPRODUTO    AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                           (PC.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PC.DTPREVCONS = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           PC.QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCOMPRA PC,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE
                           FI.CDFILIAL = FILIAL.CDFILIAL          AND
                           ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                           FI.CDFILINECCMP  = PC.CDFILIAL         AND
                           FI.IDSOLIPREV    = 'P'                 AND
                           FI.CDFILIAL      = @VCUR_FILIAL        AND
                           PC.CDPRODUTO     = PRODUTO.CDPRODUTO   AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                           (PC.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PC.DTPREVCOMP = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                           AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                           AND FI.CDFILINECCMP  = PC.CDFILIAL
                           AND FI.IDSOLIPREV    = 'P'
                           AND FI.CDFILIAL      = @VCUR_FILIAL
                           AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)
                           AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                           AND NOT EXISTS (SELECT 1
                                           FROM ROTFABLOCAL
                                           WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                             AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                         UNION ALL

                         SELECT
                           ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           ROTFABRICA ROT,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                           AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                           AND FI.CDFILINECCMP  = PC.CDFILIAL
                           AND FI.IDSOLIPREV    = 'P'
                           AND FI.CDFILIAL      = @VCUR_FILIAL
                           AND ROT.CDPRODUTO    = PC.CDPRODUTO
                           AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)
                           AND NOT EXISTS (SELECT 1
                                           FROM ROTFABLOCAL
                                           WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                             AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                         UNION ALL

                         SELECT
                           ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSPDVDIA PC,
                           ROTFABLOCAL ROT,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                           AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                           AND FI.CDFILINECCMP  = PC.CDFILIAL
                           AND FI.IDSOLIPREV    = 'P'
                           AND FI.CDFILIAL      = @VCUR_FILIAL
                           AND ROT.CDPRODUTO    = PC.CDPRODUTO
                           AND ROT.CDFILIAL     = PC.CDFILIAL
                           AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                           AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                         FROM
                           PREVCONSVMN PC,
                           FILINECE FI,
                           PRODUTO,
                           FILIAL
                         WHERE
                           FI.CDFILIAL = FILIAL.CDFILIAL          AND
                           ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                           FI.CDFILINECCMP  = PC.CDFILIALCLIE     AND
                           FI.IDSOLIPREV    = 'P'                 AND
                           FI.CDFILIAL      = @VCUR_FILIAL        AND
                           PC.CDPRODUTO     = PRODUTO.CDPRODUTO   AND
                           PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                           (PC.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (PC.DTPREVENDVMN = @V_DTATRASA)

                         UNION ALL

                         SELECT
                           IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                         FROM
                           ITEMSOLI IT,
                           PRODUTO PR,
                           FILINECE FI,
                           FILIAL
                         WHERE
                           FI.CDFILIAL = FILIAL.CDFILIAL          AND
                           ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                           FI.CDFILIAL     = @VCUR_FILIAL AND
                           IT.CDPRODUTO    = PR.CDPRODUTO AND
                           PR.CDPRODESTO   = @V_CDPRODUTO AND
                           FI.CDFILINECCMP = IT.CDFILSOLI AND
                           FI.IDSOLIPREV  <> 'P'          AND
                           (IT.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                           (IT.DTPROGENTR = @V_DTATRASA)
                       )PREVCONGER;

                       SET @V_QTASERENTREG = @V_QTASERENTREG + @V_QTDTEMP;

                          --FINAL WHILE PRINCIPAL
                       SET @V_CONTADOR   = @V_CONTADOR + 1;

                    END;
                    -- AQUI

                    /*FIM QUANTIDADE A SER ENTREGUE*/

                  /* Entra quando estiver desmarcado o parmetro 'Verificadia no til na apurao da necessidade de compras utilizando limite de segurana
                     ou quando estiver marcado o parmetro "Antecipa Entrega" */
                  END
                  ELSE BEGIN
                    IF @V_NRDIASEG > 0
                    BEGIN
                       /* Busca a quantidade consumida antecipadamente entre a data de entrega e o limite de segurana */
                       SELECT
                          @V_QTCONSANTECI = ISNULL(SUM(PREVCONGER.QTPRODCONS),0)
                       FROM
                          (SELECT
                            QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONS,
                            PRODUTO
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                            PREVCONS.DTPREVCONS >= @V_DTPROCESS AND
                            PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PREVCONS.DTPREVCONS BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                             ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                             ITEMSOLI,
                             PRODUTO,
                             FILIAL
                          WHERE
                             @V_IDENTFORPERI = 'N' AND
                             PRODUTO.CDPRODESTO        = @V_CDPRODUTO AND
                            FILIAL.CDFILCENTPME = @VCUR_FILIAL AND
                             ITEMSOLI.DTPROGENTR   >= @V_DTPROCESS      AND
                             ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'       AND
                             ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'       AND
                             PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO  AND
                             PRODUTO.CDARVPROD BETWEEN @V_CDPRODINI   AND @V_CDPRODFIN AND
                             ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL     AND
                            (ITEMSOLI.DTPROGENTR BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1)) AND
                             ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                              CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                           FROM
                                                                              CMPCENTENDIR,
                                                                              PRODUTO PI,
                                                                              PRODUTO PC
                                                                           WHERE
                                                                              CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                              CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                              ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                              PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                          UNION ALL

                          SELECT
                            QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPME,
                            PRODUTO
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            PREVCONSPME.CDFILIAL      = @VCUR_FILIAL AND
                            PREVCONSPME.DTPREVCONPME >= @V_DTPROCESS AND
                            PREVCONSPME.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO        = @V_CDPRODUTO AND
                            (PREVCONSPME.DTPREVCONPME BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))


                          UNION ALL

                          SELECT
                            QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            ITPREVCOMP,
                            PRODUTO
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            ITPREVCOMP.CDFILIAL   = @VCUR_FILIAL  AND
                            ITPREVCOMP.DTENTPRECOMP >= @V_DTPROCESS AND
                            ITPREVCOMP.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            ITPREVCOMP.IDSTITPRCOMP = 'A'                 AND
                            (ITPREVCOMP.DTENTPRECOMP BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))


                          UNION ALL

                          SELECT
                            QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCOMPRA,
                            PRODUTO
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                            PREVCOMPRA.DTPREVCOMP >= @V_DTPROCESS AND
                            PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PREVCOMPRA.DTPREVCOMP BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            PRODUTO
                          WHERE @V_IDENTFORPERI = 'N'
                            AND PC.CDFILIAL     = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                            AND PC.CDPRODUTO    = PRODUTO.CDPRODUTO
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))
                            AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                            AND NOT EXISTS (SELECT 1
                                            FROM ROTFABLOCAL
                                            WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                              AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                          UNION ALL

                          SELECT
                            ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            ROTFABRICA ROT,
                            PRODUTO
                          WHERE @V_IDENTFORPERI    = 'N'
                            AND PC.CDFILIAL        = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))
                            AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                            AND ROT.CDPRODUTO      = PC.CDPRODUTO
                            AND NOT EXISTS (SELECT 1
                                            FROM ROTFABLOCAL
                                            WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                              AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                          UNION ALL

                          SELECT
                            ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            ROTFABLOCAL ROT,
                            PRODUTO
                          WHERE @V_IDENTFORPERI    = 'N'
                            AND PC.CDFILIAL        = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) >= @V_DTPROCESS
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))
                            AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                            AND ROT.CDFILIAL       = PC.CDFILIAL
                            AND ROT.CDPRODUTO      = PC.CDPRODUTO

                          UNION ALL

                          SELECT
                            QTSOLCONVMN * PRODUTO.VRFATOCONV  AS QTPRODCONS
                          FROM
                            PREVCONSVMN,
                            PRODUTO
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            PREVCONSVMN.CDFILIALCLIE = @VCUR_FILIAL   AND
                            PREVCONSVMN.DTPREVENDVMN >= @V_DTPROCESS AND
                            PREVCONSVMN.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PREVCONSVMN.DTPREVENDVMN BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONS PC,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            FI.CDFILIAL = FILIAL.CDFILIAL     AND
                            ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                            FI.CDFILINECCMP = PC.CDFILIAL  AND
                            FI.IDSOLIPREV   = 'P'          AND
                            FI.CDFILIAL     = @VCUR_FILIAL   AND
                            PC.DTPREVCONS   >= @V_DTPROCESS AND
                            PC.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PC.DTPREVCONS BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            PC.QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCOMPRA PC,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            FI.CDFILIAL = FILIAL.CDFILIAL     AND
                            ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                            FI.CDFILINECCMP  = PC.CDFILIAL  AND
                            FI.IDSOLIPREV    = 'P'          AND
                            FI.CDFILIAL      = @VCUR_FILIAL   AND
                            PC.DTPREVCOMP    >= @V_DTPROCESS AND
                            PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PC.DTPREVCOMP BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE @V_IDENTFORPERI = 'N'
                            AND FI.CDFILIAL = FILIAL.CDFILIAL
                            AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                            AND FI.CDFILINECCMP  = PC.CDFILIAL
                            AND FI.IDSOLIPREV    = 'P'
                            AND FI.CDFILIAL      = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                            AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))
                            AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                            AND NOT EXISTS (SELECT 1
                                            FROM ROTFABLOCAL
                                            WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                              AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                          UNION ALL

                          SELECT
                            ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            ROTFABRICA ROT,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE @V_IDENTFORPERI = 'N'
                            AND FI.CDFILIAL = FILIAL.CDFILIAL
                            AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                            AND FI.CDFILINECCMP  = PC.CDFILIAL
                            AND FI.IDSOLIPREV    = 'P'
                            AND FI.CDFILIAL      = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                            AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                            AND ROT.CDPRODUTO    = PC.CDPRODUTO
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))
                            AND NOT EXISTS (SELECT 1
                                            FROM ROTFABLOCAL
                                            WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                              AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                          UNION ALL

                          SELECT
                            ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSPDVDIA PC,
                            ROTFABLOCAL ROT,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE @V_IDENTFORPERI = 'N'
                            AND FI.CDFILIAL = FILIAL.CDFILIAL
                            AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                            AND FI.CDFILINECCMP  = PC.CDFILIAL
                            AND FI.IDSOLIPREV    = 'P'
                            AND FI.CDFILIAL      = @VCUR_FILIAL
                            AND CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103)  >= @V_DTPROCESS
                            AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                            AND ROT.CDPRODUTO    = PC.CDPRODUTO
                            AND ROT.CDFILIAL     = PC.CDFILIAL
                            AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                            AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                          FROM
                            PREVCONSVMN PC,
                            FILINECE FI,
                            PRODUTO,
                            FILIAL
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            FI.CDFILIAL = FILIAL.CDFILIAL     AND
                            ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                            FI.CDFILINECCMP  = PC.CDFILIALCLIE  AND
                            FI.IDSOLIPREV    = 'P'              AND
                            FI.CDFILIAL      = @VCUR_FILIAL       AND
                            PC.DTPREVENDVMN  >= @V_DTPROCESS     AND
                            PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                            PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                            (PC.DTPREVENDVMN BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))

                          UNION ALL

                          SELECT
                            IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                          FROM
                            ITEMSOLI IT,
                            PRODUTO PR,
                            FILINECE FI,
                            FILIAL
                          WHERE
                            @V_IDENTFORPERI = 'N' AND
                            FI.CDFILIAL = FILIAL.CDFILIAL     AND
                            ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                            FI.CDFILIAL     = @VCUR_FILIAL   AND
                            IT.DTPROGENTR   >= @V_DTPROCESS AND
                            IT.CDPRODUTO    = PR.CDPRODUTO AND
                            PR.CDPRODESTO   = @V_CDPRODUTO AND
                            IT.CDPRODUTO    = PR.CDPRODUTO AND
                            FI.CDFILINECCMP = IT.CDFILSOLI AND
                            FI.IDSOLIPREV  <> 'P'          AND
                            (IT.DTPROGENTR BETWEEN @V_DTENTREGA AND (@V_DTENTREGA + @V_NRDIASEG - 1))) PREVCONGER;
                    END;

                    IF @V_QTCONSANTECI IS NULL
                    BEGIN
                       SET @V_QTCONSANTECI = 0;
                    END
                    ELSE
                    BEGIN
                       SET @V_QTCONSANTECI = @V_QTCONSANTECI * (1 + (@P_PEACRESCIMO/100));
                    END;

                    SELECT
                       @V_QTASERENTREG = ISNULL(SUM(QTPRODCONS),0)
                    FROM
                    (SELECT
                        QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONS,
                        PRODUTO
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                        PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PREVCONS.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PREVCONS.DTPREVCONS BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        ITPREVCOMP,
                        PRODUTO
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        ITPREVCOMP.CDFILIAL   = @VCUR_FILIAL  AND
                        ITPREVCOMP.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        ITPREVCOMP.IDSTITPRCOMP = 'A'                 AND
                        (ITPREVCOMP.DTENTPRECOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (ITPREVCOMP.DTENTPRECOMP BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                         ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                         ITEMSOLI,
                         PRODUTO,
                         FILIAL
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                       (ITEMSOLI.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (ITEMSOLI.DTPROGENTR BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT)) AND
                         FILIAL.CDFILCENTPME = @VCUR_FILIAL AND
                         ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'       AND
                         ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'       AND
                         PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO  AND
                         ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL     AND
                         ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                          CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                       FROM
                                                                          CMPCENTENDIR,
                                                                          PRODUTO PI,
                                                                          PRODUTO PC
                                                                       WHERE
                                                                          CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                          CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                          ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                          PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                     UNION ALL

                     SELECT
                       QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                     FROM
                       PREVCONSPME,
                       PRODUTO
                     WHERE
                       @V_IDENTFORPERI = 'N' AND
                       PREVCONSPME.CDFILIAL     = @VCUR_FILIAL  AND
                       PREVCONSPME.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                       (PREVCONSPME.DTPREVCONPME <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                       (PREVCONSPME.DTPREVCONPME BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))


                      UNION ALL

                      SELECT
                        QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCOMPRA,
                        PRODUTO
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                        PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PREVCOMPRA.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PREVCOMPRA.DTPREVCOMP BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        PRODUTO
                      WHERE @V_IDENTFORPERI = 'N'
                        AND PC.CDFILIAL     = @VCUR_FILIAL
                        AND PC.CDPRODUTO    = PRODUTO.CDPRODUTO
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                        AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                        AND NOT EXISTS (SELECT 1
                                        FROM ROTFABLOCAL
                                        WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                          AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                      UNION ALL

                      SELECT
                        ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        ROTFABRICA ROT,
                        PRODUTO
                      WHERE @V_IDENTFORPERI = 'N'
                        AND PC.CDFILIAL     = @VCUR_FILIAL
                        AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                        AND ROT.CDPRODUTO    = PC.CDPRODUTO
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                        AND NOT EXISTS (SELECT 1
                                        FROM ROTFABLOCAL
                                        WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                          AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                      UNION ALL

                      SELECT
                        ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        ROTFABLOCAL ROT,
                        PRODUTO
                      WHERE @V_IDENTFORPERI    = 'N'
                        AND PC.CDFILIAL        = @VCUR_FILIAL
                        AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                        AND ROT.CDPRODUTO      = PC.CDPRODUTO
                        AND ROT.CDFILIAL       = PC.CDFILIAL
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSVMN,
                        PRODUTO
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        PREVCONSVMN.CDFILIALCLIE  = @VCUR_FILIAL   AND
                        PREVCONSVMN.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PREVCONSVMN.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PREVCONSVMN.DTPREVENDVMN BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONS PC,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        FI.CDFILIAL = FILIAL.CDFILIAL     AND
                        ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                        FI.CDFILINECCMP = PC.CDFILIAL  AND
                        FI.IDSOLIPREV   = 'P'          AND
                        FI.CDFILIAL     = @VCUR_FILIAL   AND
                        PC.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PC.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PC.DTPREVCONS BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        PC.QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCOMPRA PC,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        FI.CDFILIAL = FILIAL.CDFILIAL     AND
                        ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                        FI.CDFILINECCMP  = PC.CDFILIAL  AND
                        FI.IDSOLIPREV    = 'P'          AND
                        FI.CDFILIAL      = @VCUR_FILIAL   AND
                        PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PC.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PC.DTPREVCOMP BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE @V_IDENTFORPERI = 'N'
                        AND FI.CDFILIAL = FILIAL.CDFILIAL
                        AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                        AND FI.CDFILINECCMP  = PC.CDFILIAL
                        AND FI.IDSOLIPREV    = 'P'
                        AND FI.CDFILIAL      = @VCUR_FILIAL
                        AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                        AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                        AND NOT EXISTS (SELECT 1
                                        FROM ROTFABLOCAL
                                        WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                          AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                      UNION ALL

                      SELECT
                        ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        ROTFABRICA ROT,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE @V_IDENTFORPERI = 'N'
                        AND FI.CDFILIAL = FILIAL.CDFILIAL
                        AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                        AND FI.CDFILINECCMP  = PC.CDFILIAL
                        AND FI.IDSOLIPREV    = 'P'
                        AND FI.CDFILIAL      = @VCUR_FILIAL
                        AND ROT.CDPRODUTO    = PC.CDPRODUTO
                        AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                        AND NOT EXISTS (SELECT 1
                                        FROM ROTFABLOCAL
                                        WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                          AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                      UNION ALL

                      SELECT
                        ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSPDVDIA PC,
                        ROTFABLOCAL ROT,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE @V_IDENTFORPERI = 'N'
                        AND FI.CDFILIAL = FILIAL.CDFILIAL
                        AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                        AND FI.CDFILINECCMP  = PC.CDFILIAL
                        AND FI.IDSOLIPREV    = 'P'
                        AND FI.CDFILIAL      = @VCUR_FILIAL
                        AND ROT.CDPRODUTO    = PC.CDPRODUTO
                        AND ROT.CDFILIAL     = PC.CDFILIAL
                        AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                        AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                        AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                      FROM
                        PREVCONSVMN PC,
                        FILINECE FI,
                        PRODUTO,
                        FILIAL
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        FI.CDFILIAL = FILIAL.CDFILIAL     AND
                        ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                        FI.CDFILINECCMP  = PC.CDFILIALCLIE  AND
                        FI.IDSOLIPREV    = 'P'              AND
                        FI.CDFILIAL      = @VCUR_FILIAL       AND
                        PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                        PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                        (PC.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (PC.DTPREVENDVMN BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                      UNION ALL

                      SELECT
                        IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                      FROM
                        ITEMSOLI IT,
                        PRODUTO PR,
                        FILINECE FI,
                        FILIAL
                      WHERE
                        @V_IDENTFORPERI = 'N' AND
                        FI.CDFILIAL = FILIAL.CDFILIAL     AND
                        ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                        FI.CDFILIAL     = @VCUR_FILIAL   AND
                        IT.CDPRODUTO    = PR.CDPRODUTO AND
                        PR.CDPRODESTO   = @V_CDPRODUTO AND
                        FI.CDFILINECCMP = IT.CDFILSOLI AND
                        FI.IDSOLIPREV  <> 'P'          AND
                        (IT.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                        (IT.DTPROGENTR BETWEEN @V_DTENTREGA + @V_NRDIASEG AND (@V_DTANTPROXENT + @V_NRDIASEGANT)))PREVCONGER;  

                  END;

                  IF @V_QTASERENTREG IS NULL
                  BEGIN
                     SET @V_QTASERENTREG = 0;
                  END
                  ELSE
                  BEGIN
                     SET @V_QTASERENTREG = @V_QTASERENTREG * (1 + (@P_PEACRESCIMO/100));
                  END;

                  SET @V_DTMAXENT = NULL;
                  SELECT
                     @V_DTMAXENT = MAX(DTENTREGA)
                  FROM
                     CALECOMP
                  WHERE
                     (CDFILIAL   = @VCUR_FILIAL)             AND
                     (CDPERIENTR = @V_CDPERIENTR) AND
                     (DTENTREGA  < @V_DTENTREGA);
                  /* Busca a quantidade j solicitada do produto entre a data de entrega e a data de entrega anterior */

                  IF @V_IDSISDOS = '3' BEGIN --Adriano GR
                    IF @V_DTPRIMENTREG IS NULL BEGIN
                       SET @V_DTMAXENT = @V_DTENTREGA - 1;
                    END;
                  END;

                  IF (@V_IDSISDOS = '3') OR (@V_IDCONSAFNECCMP = 'S') BEGIN
                    IF @V_IDENTFORPERI = 'N' BEGIN
                       SELECT /* "AF em Aberto" - Apartir da primeira entrega calculada */
                         @V_QTJASOLICITA = ISNULL(SUM((QTPROGENTAF - ISNULL(QTEFETENTRAF,0)) * PRODUTO.VRFATOCONV), 0)
                       FROM
                         AUTOFORNE,
                         ITEMAUTF,
                         PRODUTO
                       WHERE
                        (ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST)   AND
                        (ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC)   AND
                        (ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN)  AND
                        (ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO)     AND
                        (ITEMAUTF.CDFILDEST  = @VCUR_FILIAL)          AND
                        (PRODUTO.CDPRODESTO  = @V_CDPRODUTO)          AND
                        (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)   AND
                        (ITEMAUTF.DTPROGENTAF BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                         WHEN @V_DTENTREGA
                                                         THEN @V_DTENTREGA
                                                         ELSE @V_DTMAXENT + 1
                                                      END  AND @V_DTENTREGA) AND
                        (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1') AND
                        (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)     AND
                        (ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('5','4','6')) AND
                        (AUTOFORNE.IDAFFORALIM = 'N')  AND
                        (AUTOFORNE.IDSITUATUAAF IS NULL) AND
                        (ITEMAUTF.DTPROGENTAF IN
                                                (SELECT CALECOMP.DTENTREGA
                                                 FROM PERFILPROD, CALECOMP, PRODUTO
                                                 WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                                   AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                                   AND CALECOMP.CDFILIAL = @VCUR_FILIAL
                                                   AND CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR
                                                   AND PRODUTO.CDARVPROD    = (SELECT
                                                                                  MAX(B.CDARVPROD)
                                                                               FROM
                                                                                 PERFILPROD A,
                                                                                 PRODUTO B
                                                                               WHERE A.CDPRODUTO = B.CDPRODUTO
                                                                                 AND A.CDFILIAL = @VCUR_FILIAL
                                                                                 AND CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                                   AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL)));


                       SELECT /* "AF em Aberto" - Apartir da primeira entrega calculada */
                         @V_QTJASOLICITADAFP = ISNULL(SUM((QTPROGENTAF - ISNULL(QTEFETENTRAF,0)) * PRODUTO.VRFATOCONV), 0)
                       FROM
                         AUTOFORNE,
                         ITEMAUTF,
                         PRODUTO
                       WHERE
                        (ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST)   AND
                        (ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC)   AND
                        (ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN)  AND
                        (ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO)     AND
                        (ITEMAUTF.CDFILDEST  = @VCUR_FILIAL)          AND
                        (PRODUTO.CDPRODESTO  = @V_CDPRODUTO)          AND
                        (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)   AND
                        (ITEMAUTF.DTPROGENTAF BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                         WHEN @V_DTENTREGA
                                                         THEN @V_DTENTREGA
                                                         ELSE @V_DTMAXENT + 1
                                                      END  AND @V_DTENTREGA) AND
                        (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1') AND
                        (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)     AND
                        (ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('5','4','6')) AND
                        (AUTOFORNE.IDAFFORALIM = 'N')  AND
                        (AUTOFORNE.IDSITUATUAAF IS NULL) AND
                        (ITEMAUTF.DTPROGENTAF IN
                                                (SELECT CALECOMP.DTENTREGA
                                                 FROM PERFILPROD, CALECOMP, PRODUTO
                                                 WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                                   AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                                   AND CALECOMP.CDFILIAL = @VCUR_FILIAL
                                                   AND CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR
                                                   AND PRODUTO.CDARVPROD    = (SELECT
                                                                                  MAX(B.CDARVPROD)
                                                                               FROM
                                                                                 PERFILPROD A,
                                                                                 PRODUTO B
                                                                               WHERE A.CDPRODUTO = B.CDPRODUTO
                                                                                 AND A.CDFILIAL = @VCUR_FILIAL
                                                                                 AND CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                                   AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL))) AND
                      (ITEMAUTF.DTPROGENTAF NOT IN
                                                (SELECT CALECOMP.DTENTREGA
                                                 FROM PERFILPROD, CALECOMP, PRODUTO
                                                 WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                                   AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                                   AND CALECOMP.CDFILIAL = @VCUR_FILIAL
                                                   AND CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR
                                                   AND PRODUTO.CDARVPROD    = (SELECT
                                                                                  MAX(B.CDARVPROD)
                                                                               FROM
                                                                                 PERFILPROD A,
                                                                                 PRODUTO B
                                                                               WHERE A.CDPRODUTO = B.CDPRODUTO
                                                                                 AND A.CDFILIAL = @VCUR_FILIAL
                                                                                 AND CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                                   AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL)));

                        SET @V_QTJASOLICITA =  @V_QTJASOLICITA + @V_QTJASOLICITADAFP;
                       /*AFs Futuras. Ou seja, a data de entrada da NF  superior a data de processamento da filial*/
                       SELECT @V_QTAFFUTURA = ISNULL(SUM(ISNULL(QTEFETENTRAF,0) * PRODUTO.VRFATOCONV), 0)
                         FROM ITEMAUTF, PRODUTO
                        WHERE ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO
                          AND ITEMAUTF.CDFILDEST  = @VCUR_FILIAL
                          AND PRODUTO.CDPRODESTO  = @V_CDPRODUTO
                          AND ISNULL(QTEFETENTRAF, 0) > 0
                          AND DTEFETENTAF > @V_DTPROCESS
                          AND ITEMAUTF.DTEFETENTAF BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                              WHEN @V_DTENTREGA
                                                              THEN @V_DTENTREGA
                                                              ELSE @V_DTMAXENT + 1
                                                           END  AND @V_DTENTREGA
                          AND ISNULL(ITEMAUTF.IDBAIXITMFUTURA, 'X') = 'S'
                          AND ITEMAUTF.DTPROGENTAF IN (SELECT CALECOMP.DTENTREGA
                                                         FROM PERFILPROD, CALECOMP, PRODUTO
                                                        WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                                          AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                                          AND CALECOMP.CDFILIAL    = @VCUR_FILIAL
                                                          AND CALECOMP.CDPERIENTR  = PERFILPROD.CDPERIENTR
                                                          AND PRODUTO.CDARVPROD    = (SELECT
                                                                                        MAX(B.CDARVPROD)
                                                                                      FROM
                                                                                        PERFILPROD A,
                                                                                        PRODUTO B
                                                                                      WHERE
                                                                                        A.CDPRODUTO = B.CDPRODUTO AND
                                                                                        A.CDFILIAL = @VCUR_FILIAL AND
                                                                                        CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                                          AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL) );

                        /*Pedidos do OL em aberto*/
                       SELECT
                         @V_QTJASOLICPEXOL = ISNULL(SUM((QTPROGENPEOL - ISNULL(QTEFETENPEOL,0)) * PRODUTO.VRFATOCONV), 0)
                       FROM
                         PEDIDOEXOL,
                         ITEMPEDEXOL,
                         PRODUTO
                       WHERE
                        (ITEMPEDEXOL.CDFILDEST = PEDIDOEXOL.CDFILDEST) AND
                        (ITEMPEDEXOL.CDFILLANC = PEDIDOEXOL.CDFILLANC) AND
                        (ITEMPEDEXOL.NRPEDEXOL = PEDIDOEXOL.NRPEDEXOL) AND
                        (ITEMPEDEXOL.CDPRODUTO = PRODUTO.CDPRODUTO)   AND
                        (ITEMPEDEXOL.CDFILDEST = @VCUR_FILIAL) AND
                        (PRODUTO.CDPRODESTO = @V_CDPRODUTO) AND
                        (QTPROGENPEOL - ISNULL(QTEFETENPEOL, 0) > 0)   AND
                        (ISNULL(ITEMPEDEXOL.IDITEMAJUSTE, 'N') = 'N')  AND
                        (ITEMPEDEXOL.DTPROGENPEOL BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                             WHEN @V_DTENTREGA
                                                             THEN @V_DTENTREGA
                                                             ELSE @V_DTMAXENT + 1
                                                          END  AND @V_DTENTREGA) AND
                        (ITEMPEDEXOL.IDBAIXENPEOL IS NULL OR ITEMPEDEXOL.IDBAIXENPEOL = '1') AND
                        (QTPROGENPEOL - ISNULL(QTEFETENPEOL, 0) > 0)     AND
                        (ISNULL(PEDIDOEXOL.IDBAIXEXOL, '0') NOT IN ('5','4')) AND
                        (ISNULL(PEDIDOEXOL.IDBAIXEXOL, '1') = '1') AND
                        (ITEMPEDEXOL.DTPROGENPEOL IN
                                     (SELECT CALECOMP.DTENTREGA
                                      FROM PERFILPROD, CALECOMP, PRODUTO
                                      WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                        AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                        AND CALECOMP.CDFILIAL = @VCUR_FILIAL
                                        AND CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR
                                        AND PRODUTO.CDARVPROD    = (SELECT MAX(B.CDARVPROD)
                                                                    FROM PERFILPROD A, PRODUTO B
                                                                    WHERE A.CDPRODUTO = B.CDPRODUTO
                                                                      AND A.CDFILIAL = @VCUR_FILIAL
                                                                      AND CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                        AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL)));

                       SET @V_QTJASOLICITA = @V_QTJASOLICITA + @V_QTAFFUTURA + @V_QTJASOLICPEXOL;
                    END
                    ELSE BEGIN
                      SELECT /* "AF em Aberto" - Apartir da primeira entrega calculada */
                         @V_QTJASOLICITA = ISNULL(SUM((QTPROGENTAF - ISNULL(QTEFETENTRAF,0)) * PRODUTO.VRFATOCONV), 0)
                      FROM
                        AUTOFORNE,
                        ITEMAUTF,
                        PRODUTO
                      WHERE
                        ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST  AND
                        ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC  AND
                        ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN AND
                        ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO    AND
                        ITEMAUTF.CDFILDEST  = @VCUR_FILIAL         AND
                        PRODUTO.CDPRODESTO  = @V_CDPRODUTO         AND
                        ITEMAUTF.DTPROGENTAF = @V_DTENTREGA        AND
                        (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1') AND
                        QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0     AND
                        ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('5','4','6') AND
                        AUTOFORNE.IDAFFORALIM = 'N'  AND
                        AUTOFORNE.IDSITUATUAAF IS NULL;

                      /*AFs Futuras. Ou seja, a data de entrada da NF  superior a data de processamento da filial*/
                      SELECT @V_QTAFFUTURA = ISNULL(SUM(ISNULL(QTEFETENTRAF,0) * PRODUTO.VRFATOCONV), 0)
                      FROM ITEMAUTF, PRODUTO
                      WHERE ITEMAUTF.CDFILDEST    = @VCUR_FILIAL
                        AND PRODUTO.CDPRODESTO    = @V_CDPRODUTO
                        AND ITEMAUTF.DTEFETENTAF  = @V_DTENTREGA
                        AND ITEMAUTF.CDPRODUTO    = PRODUTO.CDPRODUTO
                        AND ISNULL(QTEFETENTRAF, 0) > 0
                        AND DTEFETENTAF > @V_DTPROCESS
                        AND ISNULL(ITEMAUTF.IDBAIXITMFUTURA, 'X') = 'S';

                      SET @V_QTJASOLICITA = @V_QTJASOLICITA + @V_QTAFFUTURA;
                    END;
                  END
                  ELSE BEGIN
                    SELECT
                       @V_QTJASOLICITA = ISNULL(SUM(QTSOLIPROD*PRODUTO.VRFATOCONV), 0)
                    FROM
                       SOLICITA,
                       ITEMSOLI,
                       PRODUTO
                    WHERE
                       (PRODUTO.CDPRODESTO = @V_CDPRODUTO)    AND
                       (ITEMSOLI.CDFILSOLI = @VCUR_FILIAL)          AND
                       (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)   AND
                       (ITEMSOLI.DTPROGENTR >= @V_DTPROCESS)       AND
                       (ITEMSOLI.CDFILSOLI = SOLICITA.CDFILSOLI)  AND
                       (ITEMSOLI.CDFILLAN  = SOLICITA.CDFILLANCA) AND
                       (ITEMSOLI.NRSOLICMP = SOLICITA.NRSOLICMP)  AND
                       (ISNULL(SOLICITA.IDSOLEXTRA, 'N') = 'N')      AND
                       (ITEMSOLI.DTPROGENTR BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                       WHEN @V_DTENTREGA
                                                       THEN @V_DTENTREGA
                                                       ELSE @V_DTMAXENT + 1
                                                    END  AND @V_DTENTREGA);
                  END;
                  SET @V_QTPROGENTAF = 0;
                  SET @V_QTSOLIPROD  = 0;
                  /*CONSUUTA A QUANTIDADE DE AF PARA SER EXIBIDO NA PREVIA CMP03802.QR2*/
                  SELECT /* "AF em Aberto" - Apartir da primeira entrega calculada */
                      @V_QTPROGENTAF = ISNULL(SUM((QTPROGENTAF - ISNULL(QTEFETENTRAF,0)) * PRODUTO.VRFATOCONV), 0)
                    FROM
                      AUTOFORNE,
                      ITEMAUTF,
                      PRODUTO
                    WHERE
                     (ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST)   AND
                     (ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC)   AND
                     (ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN)  AND
                     (ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO)     AND
                     (ITEMAUTF.CDFILDEST  = @VCUR_FILIAL)          AND
                     (PRODUTO.CDPRODESTO  = @V_CDPRODUTO)          AND
                     (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)   AND
                     (ITEMAUTF.DTPROGENTAF BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                      WHEN @V_DTENTREGA
                                                      THEN @V_DTENTREGA
                                                      ELSE @V_DTMAXENT + 1
                                                   END  AND @V_DTENTREGA) AND
                     (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1') AND
                     (QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0)     AND
                     (ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('5','4','6')) AND
                     (AUTOFORNE.IDAFFORALIM = 'N')  AND
                     (AUTOFORNE.IDSITUATUAAF IS NULL);

                  /*CONSULTA A QUANTIDADE DE AF+PEDIDO OL PARA SER EXIBIDO NA PREVIA CMP03802.QR2*/
                  SELECT
                    @V_QTPROGENTAF = ISNULL(SUM((QTPROGENPEOL - ISNULL(QTEFETENPEOL,0)) * PRODUTO.VRFATOCONV), 0) + @V_QTPROGENTAF
                  FROM
                    PEDIDOEXOL,
                    ITEMPEDEXOL,
                    PRODUTO
                  WHERE
                   (ITEMPEDEXOL.CDFILDEST = PEDIDOEXOL.CDFILDEST) AND
                   (ITEMPEDEXOL.CDFILLANC = PEDIDOEXOL.CDFILLANC) AND
                   (ITEMPEDEXOL.NRPEDEXOL = PEDIDOEXOL.NRPEDEXOL) AND
                   (ITEMPEDEXOL.CDPRODUTO = PRODUTO.CDPRODUTO)   AND
                   (ITEMPEDEXOL.CDFILDEST = @VCUR_FILIAL) AND
                   (PRODUTO.CDPRODESTO = @V_CDPRODUTO) AND
                   (QTPROGENPEOL - ISNULL(QTEFETENPEOL, 0) > 0)   AND
                   (ISNULL(ITEMPEDEXOL.IDITEMAJUSTE, 'N') = 'N')  AND
                   (ITEMPEDEXOL.DTPROGENPEOL BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                        WHEN @V_DTENTREGA
                                                        THEN @V_DTENTREGA
                                                        ELSE @V_DTMAXENT + 1
                                                     END  AND @V_DTENTREGA) AND
                   (ITEMPEDEXOL.IDBAIXENPEOL IS NULL OR ITEMPEDEXOL.IDBAIXENPEOL = '1') AND
                   (QTPROGENPEOL - ISNULL(QTEFETENPEOL, 0) > 0)     AND
                   (ISNULL(PEDIDOEXOL.IDBAIXEXOL, '0') NOT IN ('5','4')) AND
                   (ISNULL(PEDIDOEXOL.IDBAIXEXOL, '1') = '1') AND
                   (ITEMPEDEXOL.DTPROGENPEOL IN
                                (SELECT CALECOMP.DTENTREGA
                                 FROM PERFILPROD, CALECOMP, PRODUTO
                                 WHERE PERFILPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                   AND PERFILPROD.CDFILIAL  = @VCUR_FILIAL
                                   AND CALECOMP.CDFILIAL = @VCUR_FILIAL
                                   AND CALECOMP.CDPERIENTR = PERFILPROD.CDPERIENTR
                                   AND PRODUTO.CDARVPROD    = (SELECT MAX(B.CDARVPROD)
                                                               FROM PERFILPROD A, PRODUTO B
                                                               WHERE A.CDPRODUTO = B.CDPRODUTO
                                                                 AND A.CDFILIAL = @VCUR_FILIAL
                                                                 AND CHARINDEX(B.CDARVPROD, @V_CDARVPROD) = 1)
                                   AND CALECOMP.DTENTREGA BETWEEN @V_DTPROCESS AND DATEADD(MM,1, @P_DTFINAL)));

                  /*CONSUULTA A QUANTIDADE DE SOLICITAO PARA SER EXIBIDO NA PREVIA CMP03802.QR2*/
                  SELECT
                     @V_QTSOLIPROD = ISNULL(SUM(QTSOLIPROD*PRODUTO.VRFATOCONV), 0)
                  FROM
                     SOLICITA,
                     ITEMSOLI,
                     PRODUTO
                  WHERE
                     (PRODUTO.CDPRODESTO = @V_CDPRODUTO)    AND
                     (ITEMSOLI.CDFILSOLI = @VCUR_FILIAL)          AND
                     (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)   AND
                     (ITEMSOLI.DTPROGENTR >= @V_DTPROCESS)       AND
                     (ITEMSOLI.CDFILSOLI = SOLICITA.CDFILSOLI)  AND
                     (ITEMSOLI.CDFILLAN  = SOLICITA.CDFILLANCA) AND
                     (ITEMSOLI.NRSOLICMP = SOLICITA.NRSOLICMP)  AND
                     (ISNULL(SOLICITA.IDSOLEXTRA, 'N') = 'N')      AND
                     (ITEMSOLI.DTPROGENTR BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                     WHEN @V_DTENTREGA
                                                     THEN @V_DTENTREGA
                                                     ELSE @V_DTMAXENT + 1
                                                  END  AND @V_DTENTREGA)
                   AND NOT EXISTS (SELECT 1
                                     FROM ITEMSOLI I
                                    WHERE I.DTPROGENCONS = ITEMSOLI.DTPROGENTR
                                      AND I.CDPRODUTCONS = ITEMSOLI.CDPRODUTO
                                      AND I.CDFILSOLCONS = ITEMSOLI.CDFILSOLI
                                      AND I.CDFILLANCONS = ITEMSOLI.CDFILLAN
                                      AND I.NRSOLCMPCONS = ITEMSOLI.NRSOLICMP );
                  SET @V_NRSEQCMPGER = NULL;

                  IF @V_IDCONSAFNECCMP = 'S' BEGIN
                     /*CONSUULTA SEQUENCIAL DE AF PARA SER EXIBIDO NA PREVIA CMP03802.QR2*/
                     SELECT @V_NRSEQCMPGER = ISNULL(MAX(AUTOFORNE.NRAUTOFORN), ' ')
                       FROM AUTOFORNE, ITEMAUTF, PRODUTO
                      WHERE ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST
                        AND ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC
                        AND ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN
                        AND ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO
                        AND ITEMAUTF.CDFILDEST  = @VCUR_FILIAL
                        AND PRODUTO.CDPRODESTO  = @V_CDPRODUTO
                        AND (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1')
                        AND QTPROGENTAF - ISNULL(QTEFETENTRAF, 0) > 0
                        AND ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('4', '5', '6')
                        AND AUTOFORNE.IDAFFORALIM = 'N'
                        AND AUTOFORNE.IDSITUATUAAF IS NULL
                        AND ITEMAUTF.DTPROGENTAF BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                            WHEN @V_DTENTREGA
                                                            THEN @V_DTENTREGA
                                                            ELSE @V_DTMAXENT + 1
                                                         END  AND @V_DTENTREGA
                        AND ISNULL(AUTOFORNE.IDAFEXPIRADA, 'N') = 'N';
                     IF @V_NRSEQCMPGER = ' ' BEGIN
                        /*SE NO EXISTIR SEQUENCIAL DE AF CONSUULTA SEQUENCIAL DE PEDIDO OL PARA SER EXIBIDO NA PREVIA CMP03802.QR2*/
                        SELECT @V_NRSEQCMPGER = ISNULL(MAX(ITEMPEDEXOL.NRPEDEXOL), ' ')
                          FROM PEDIDOEXOL, ITEMPEDEXOL, PRODUTO
                         WHERE ITEMPEDEXOL.CDFILDEST = PEDIDOEXOL.CDFILDEST
                           AND ITEMPEDEXOL.CDFILLANC = PEDIDOEXOL.CDFILLANC
                           AND ITEMPEDEXOL.NRPEDEXOL = PEDIDOEXOL.NRPEDEXOL
                           AND ITEMPEDEXOL.CDPRODUTO = PRODUTO.CDPRODUTO
                           AND ITEMPEDEXOL.CDFILDEST = @VCUR_FILIAL
                           AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                           AND (ITEMPEDEXOL.IDBAIXENPEOL IS NULL OR ITEMPEDEXOL.IDBAIXENPEOL = '1')
                           AND QTPROGENPEOL - ISNULL(QTEFETENPEOL, 0) > 0
                           AND ISNULL(ITEMPEDEXOL.IDITEMAJUSTE, 'N') = 'N'
                           AND ISNULL(PEDIDOEXOL.IDBAIXEXOL, '0') NOT IN ('4', '5')
                           AND ISNULL(PEDIDOEXOL.IDBAIXEXOL, '1') = '1'
                           AND ITEMPEDEXOL.DTPROGENPEOL BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                                   WHEN @V_DTENTREGA
                                                                   THEN @V_DTENTREGA
                                                                   ELSE @V_DTMAXENT + 1
                                                                END  AND @V_DTENTREGA;
                     END;
                  END
                  ELSE BEGIN
                     SELECT @V_NRSEQCMPGER = ISNULL(MAX(SOLICITA.NRSOLICMP), ' ')
                       FROM
                         SOLICITA,
                         ITEMSOLI,
                         PRODUTO
                      WHERE
                         (PRODUTO.CDPRODESTO = @V_CDPRODUTO)    AND
                         (ITEMSOLI.CDFILSOLI = @VCUR_FILIAL)          AND
                         (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)   AND
                         (ITEMSOLI.DTPROGENTR >= @V_DTPROCESS)       AND
                         (ITEMSOLI.CDFILSOLI = SOLICITA.CDFILSOLI)  AND
                         (ITEMSOLI.CDFILLAN  = SOLICITA.CDFILLANCA) AND
                         (ITEMSOLI.NRSOLICMP = SOLICITA.NRSOLICMP)  AND
                         (ISNULL(SOLICITA.IDSOLEXTRA, 'N') = 'N')      AND
                         (ITEMSOLI.DTPROGENTR BETWEEN CASE ISNULL( @V_DTMAXENT, @V_DTENTREGA)
                                                          WHEN @V_DTENTREGA
                                                          THEN @V_DTENTREGA
                                                          ELSE @V_DTMAXENT + 1
                                                       END  AND @V_DTENTREGA)
                       AND NOT EXISTS (SELECT 1
                                         FROM ITEMSOLI I
                                        WHERE I.DTPROGENCONS = ITEMSOLI.DTPROGENTR
                                          AND I.CDPRODUTCONS = ITEMSOLI.CDPRODUTO
                                          AND I.CDFILSOLCONS = ITEMSOLI.CDFILSOLI
                                          AND I.CDFILLANCONS = ITEMSOLI.CDFILLAN
                                          AND I.NRSOLCMPCONS = ITEMSOLI.NRSOLICMP );
                  END;
                  IF @V_QTJASOLICITA IS NULL
                  BEGIN
                     SET @V_QTJASOLICITA = 0;
                  END;
                  /* Entra quando estiver marcado o parmetro 'Verificadia no til na apurao da necessidade de compras utilizando limite de segurana
                     e quando estiver marcado o parmetro "Atrasa Entrega" */
                  IF (@V_PERFILPROD_DNUTIL = 'S' AND @V_PERFILPROD_SITENTR = 'A') BEGIN
                     SELECT
                        @V_DTPRIUTIPROD = MIN(DTPREVCONS)
                     FROM
                        (SELECT
                          DTPREVCONS
                        FROM
                          PREVCONS,
                          PRODUTO
                        WHERE
                          PREVCONS.CDFILIAL  = @VCUR_FILIAL  AND
                          PREVCONS.CDPRODUTO = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PREVCONS.DTPREVCONS BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          DTENTPRECOMP AS DTPREVCONS
                        FROM
                          ITPREVCOMP,
                          PRODUTO
                        WHERE
                          ITPREVCOMP.CDFILIAL  = @VCUR_FILIAL  AND
                          ITPREVCOMP.CDPRODUTO = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO   = @V_CDPRODUTO AND
                          ITPREVCOMP.IDSTITPRCOMP = 'A' AND
                          (ITPREVCOMP.DTENTPRECOMP BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                           ITEMSOLI.DTPROGENTR AS DTPREVCONS
                        FROM
                           ITEMSOLI,
                           PRODUTO,
                           FILIAL
                        WHERE
                           FILIAL.CDFILCENTPME = @VCUR_FILIAL         AND
                           PRODUTO.CDPRODESTO  = @V_CDPRODUTO         AND
                           ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'     AND
                           ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'     AND
                           PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO     AND
                           ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL      AND
                          (ITEMSOLI.DTPROGENTR BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT)) AND
                           ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                            CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                         FROM
                                                                            CMPCENTENDIR,
                                                                            PRODUTO PI,
                                                                            PRODUTO PC
                                                                         WHERE
                                                                            CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                            CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                            ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                            PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                        UNION ALL

                        SELECT
                          DTPREVCONPME  AS DTPREVCONS
                        FROM
                          PREVCONSPME,
                          PRODUTO
                        WHERE
                          PREVCONSPME.CDFILIAL   = @VCUR_FILIAL  AND
                          PREVCONSPME.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO     = @V_CDPRODUTO AND
                          (PREVCONSPME.DTPREVCONPME BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))


                        UNION ALL

                        SELECT
                          DTPREVCOMP AS DTPREVCONS
                        FROM
                          PREVCOMPRA,
                          PRODUTO
                        WHERE
                          PREVCOMPRA.CDFILIAL  = @VCUR_FILIAL  AND
                          PREVCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO   = @V_CDPRODUTO AND
                          (PREVCOMPRA.DTPREVCOMP BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND PC.CDPRODUTO       = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)


                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND ROT.CDPRODUTO      = PC.CDPRODUTO
                          AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND ROT.CDFILIAL       = PC.CDFILIAL
                          AND ROT.CDPRODUTO      = PC.CDPRODUTO
                          AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          DTPREVENDVMN AS DTPREVCONS
                        FROM
                          PREVCONSVMN,
                          PRODUTO
                        WHERE
                          PREVCONSVMN.CDFILIALCLIE = @VCUR_FILIAL   AND
                          PREVCONSVMN.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                          (PREVCONSVMN.DTPREVENDVMN BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          PC.DTPREVCONS
                        FROM
                          PREVCONS PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP = PC.CDFILIAL          AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          FI.IDSOLIPREV   = 'P'                  AND
                          FI.CDFILIAL     = @VCUR_FILIAL         AND
                          PC.CDPRODUTO    = PRODUTO.CDPRODUTO    AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                          (PC.DTPREVCONS BETWEEN (@V_DTENTREGA)  AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          PC.DTPREVCOMP AS DTPREVCONS
                        FROM
                          PREVCOMPRA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP  = PC.CDFILIAL         AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          FI.IDSOLIPREV    = 'P'                 AND
                          FI.CDFILIAL      = @VCUR_FILIAL        AND
                          PC.CDPRODUTO     = PRODUTO.CDPRODUTO   AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                          (PC.DTPREVCOMP BETWEEN (@V_DTENTREGA)  AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)
                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND ROT.CDFILIAL     = PC.CDFILIAL
                          AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          PC.DTPREVENDVMN AS DTPREVCONS
                        FROM
                          PREVCONSVMN PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP  = PC.CDFILIALCLIE      AND
                          FI.CDFILIAL      = FILIAL.CDFILIAL      AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'  AND
                          FI.IDSOLIPREV    = 'P'                  AND
                          FI.CDFILIAL      = @VCUR_FILIAL         AND
                          PC.CDPRODUTO     = PRODUTO.CDPRODUTO    AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO       AND
                          (PC.DTPREVENDVMN BETWEEN (@V_DTENTREGA) AND (@V_DTANTPROXENT))

                        UNION ALL

                        SELECT
                          IT.DTPROGENTR AS DTPREVCONS
                        FROM
                          ITEMSOLI IT,
                          PRODUTO PR,
                          FILINECE FI,
                          FILIAL
                        WHERE
                          FI.CDFILIAL = @VCUR_FILIAL             AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          IT.CDPRODUTO    = PR.CDPRODUTO         AND
                          PR.CDPRODESTO   = @V_CDPRODUTO         AND
                          FI.CDFILINECCMP = IT.CDFILSOLI         AND
                          FI.IDSOLIPREV  <> 'P'                  AND
                          (IT.DTPROGENTR BETWEEN (@V_DTENTREGA)  AND (@V_DTANTPROXENT))) PREVCONGER;
                  /* Entra quando estiver desmarcado o parmetro 'Verificadia no til na apurao da necessidade de compras utilizando limite de segurana
                     ou quando estiver marcado o parmetro "Antecipa Entrega" */
                  END
                  ELSE BEGIN
                     SELECT
                        @V_DTPRIUTIPROD = MIN(DTPREVCONS)
                     FROM
                        (SELECT
                          DTPREVCONS
                        FROM
                          PREVCONS,
                          PRODUTO
                        WHERE
                          PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                          PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PREVCONS.DTPREVCONS BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          DTENTPRECOMP AS DTPREVCONS
                        FROM
                          ITPREVCOMP,
                          PRODUTO
                        WHERE
                          ITPREVCOMP.CDFILIAL     = @VCUR_FILIAL  AND
                          ITPREVCOMP.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO      = @V_CDPRODUTO AND
                          ITPREVCOMP.IDSTITPRCOMP = 'A' AND
                          (ITPREVCOMP.DTENTPRECOMP BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                           ITEMSOLI.DTPROGENTR AS DTPREVCONS
                        FROM
                           ITEMSOLI,
                           PRODUTO,
                           FILIAL
                        WHERE
                           FILIAL.CDFILCENTPME = @VCUR_FILIAL     AND
                           PRODUTO.CDPRODESTO  = @V_CDPRODUTO     AND
                           ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N' AND
                           ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S' AND
                           PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO AND
                           ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL  AND
                          (ITEMSOLI.DTPROGENTR BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT)) AND
                           ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                            CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                         FROM
                                                                            CMPCENTENDIR,
                                                                            PRODUTO PI,
                                                                            PRODUTO PC
                                                                         WHERE
                                                                            CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                            CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                            ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                            PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                        UNION ALL

                        SELECT
                          DTPREVCONPME  AS DTPREVCONS
                        FROM
                          PREVCONSPME,
                          PRODUTO
                        WHERE
                          PREVCONSPME.CDFILIAL  = @VCUR_FILIAL  AND
                          PREVCONSPME.CDPRODUTO = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO    = @V_CDPRODUTO AND
                          (PREVCONSPME.DTPREVCONPME BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))


                        UNION ALL

                        SELECT
                          DTPREVCOMP AS DTPREVCONS
                        FROM
                          PREVCOMPRA,
                          PRODUTO
                        WHERE
                          PREVCOMPRA.CDFILIAL  = @VCUR_FILIAL  AND
                          PREVCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO   = @V_CDPRODUTO AND
                          (PREVCOMPRA.DTPREVCOMP BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND PC.CDPRODUTO       = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND ROT.CDPRODUTO      = PC.CDPRODUTO
                          AND ROT.CDSUBPRODUTO   = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          PRODUTO
                        WHERE PC.CDFILIAL        = @VCUR_FILIAL
                          AND ROT.CDFILIAL       = PC.CDFILIAL
                          AND ROT.CDPRODUTO      = PC.CDPRODUTO
                          AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          DTPREVENDVMN AS DTPREVCONS
                        FROM
                          PREVCONSVMN,
                          PRODUTO
                        WHERE
                          PREVCONSVMN.CDFILIALCLIE = @VCUR_FILIAL AND
                          PREVCONSVMN.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                          (PREVCONSVMN.DTPREVENDVMN BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          PC.DTPREVCONS
                        FROM
                          PREVCONS PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP = PC.CDFILIAL          AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          FI.IDSOLIPREV = 'P'                    AND
                          FI.CDFILIAL   = @VCUR_FILIAL           AND
                          PC.CDPRODUTO  = PRODUTO.CDPRODUTO      AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                          (PC.DTPREVCONS BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          PC.DTPREVCOMP AS DTPREVCONS
                        FROM
                          PREVCOMPRA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP  = PC.CDFILIAL         AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          FI.IDSOLIPREV = 'P'                    AND
                          FI.CDFILIAL   = @VCUR_FILIAL           AND
                          PC.CDPRODUTO  = PRODUTO.CDPRODUTO      AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                          (PC.DTPREVCOMP BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) AS DTPREVCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND ROT.CDFILIAL     = PC.CDFILIAL
                          AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          PC.DTPREVENDVMN AS DTPREVCONS
                        FROM
                          PREVCONSVMN PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          FI.CDFILINECCMP  = PC.CDFILIALCLIE     AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          FI.IDSOLIPREV = 'P'                    AND
                          FI.CDFILIAL   = @VCUR_FILIAL           AND
                          PC.CDPRODUTO  = PRODUTO.CDPRODUTO      AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO      AND
                          (PC.DTPREVENDVMN BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))

                        UNION ALL

                        SELECT
                          IT.DTPROGENTR AS DTPREVCONS
                        FROM
                          ITEMSOLI IT,
                          PRODUTO PR,
                          FILINECE FI,
                          FILIAL
                        WHERE
                          FI.CDFILIAL = @VCUR_FILIAL             AND
                          FI.CDFILIAL = FILIAL.CDFILIAL          AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N' AND
                          IT.CDPRODUTO    = PR.CDPRODUTO         AND
                          PR.CDPRODESTO   = @V_CDPRODUTO         AND
                          FI.CDFILINECCMP = IT.CDFILSOLI         AND
                          FI.IDSOLIPREV  <> 'P'                  AND
                          (IT.DTPROGENTR BETWEEN (@V_DTENTREGA + @V_NRDIASEG) AND (@V_DTANTPROXENT + @V_NRDIASEGANT))) PREVCONGER;
                  END;

                  IF @V_IDPRIVEZPROD = 'S'
                  BEGIN
                     IF @V_IDPRIENTRFP = 'S' BEGIN
                       SET @V_QTESTAFPEND   = 0;
                       SET @V_QTESTAFPANT   = 0;
                       SET @V_QTESTAFPDEP   = 0;
                       SET @V_QTAFANTPRIENT = 0;
                     END;
                     IF @V_DTPRIMENTREG IS NULL BEGIN
                       SET @V_QTAFANTPRIENT = @V_QTAFANTPRIENT + @V_QTESTONECCMP;
                     END;

                     SET @V_QTCONATEPREN = 0;
                     SET @V_QTESTONECCMP = 0;
                     SET @V_QTPRCNVCOMPR = 0;
                     SET @V_QTTEORNECCMP = 0;
                     SET @V_QTESTOUTILIZ = 0;
                     SET @V_QTESTOQATUAL = 0;
                     SET @V_QTORIGNECCMP = 0;
                     SET @V_QTPRACOMPRAR = 0;
                     SET @V_QTESTOSEGU   = 0;

                     /* Busca a quantidade consumida entre a data de processamento e a primeira entrega */

                     SELECT
                        @V_QTCONATEPREN = ISNULL(SUM(QTPRODCONS),0)
                     FROM
                        (SELECT
                          QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONS,
                          PRODUTO
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          PREVCONS.CDFILIAL   = @VCUR_FILIAL  AND
                          PREVCONS.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PREVCONS.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PREVCONS.DTPREVCONS BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)
                        UNION ALL

                        SELECT
                          QTPREVCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          ITPREVCOMP,
                          PRODUTO
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          ITPREVCOMP.CDFILIAL   = @VCUR_FILIAL  AND
                          ITPREVCOMP.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          ITPREVCOMP.IDSTITPRCOMP = 'A'                 AND
                          (ITPREVCOMP.DTENTPRECOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (ITPREVCOMP.DTENTPRECOMP BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCOMPRA,
                          PRODUTO
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          PREVCOMPRA.CDFILIAL   = @VCUR_FILIAL  AND
                           PREVCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO AND
                           PRODUTO.CDPRODESTO    = @V_CDPRODUTO AND
                          (PREVCOMPRA.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PREVCOMPRA.DTPREVCOMP BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)


                        UNION ALL

                        SELECT
                           ITEMSOLI.QTSOLIPROD * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                           ITEMSOLI,
                           PRODUTO,
                           FILIAL
                        WHERE
                           @V_IDENTFORPERI = 'N' AND
                           FILIAL.CDFILCENTPME = @VCUR_FILIAL          AND
                           ISNULL(ITEMSOLI.IDITMCONS, 'N')  = 'N'         AND
                           ISNULL(ITEMSOLI.IDSOLIAPROV, 'S')= 'S'         AND
                           PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO      AND
                           PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                          (ITEMSOLI.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (ITEMSOLI.DTPROGENTR BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1) AND
                           ITEMSOLI.CDFILSOLI  = FILIAL.CDFILIAL     AND
                           ITEMSOLI.CDFILSOLI+ITEMSOLI.CDPRODUTO NOT IN (SELECT
                                                                            CMPCENTENDIR.CDFILIAL+CMPCENTENDIR.CDPRODUTO
                                                                         FROM
                                                                            CMPCENTENDIR,
                                                                            PRODUTO PI,
                                                                            PRODUTO PC
                                                                         WHERE
                                                                            CMPCENTENDIR.CDFILIAL  = ITEMSOLI.CDFILSOLI AND
                                                                            CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                            ITEMSOLI.CDPRODUTO     = PI.CDPRODUTO AND
                                                                            PI.CDARVPROD LIKE PC.CDARVPROD+'%')

                        UNION ALL

                        SELECT
                          QTPREVCONPME * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPME,
                          PRODUTO
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          PREVCONSPME.CDFILIAL     = @VCUR_FILIAL  AND
                          PREVCONSPME.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO       = @V_CDPRODUTO AND
                          (PREVCONSPME.DTPREVCONPME <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PREVCONSPME.DTPREVCONPME BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)


                        UNION ALL


                        SELECT
                          PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          PRODUTO
                        WHERE @V_IDENTFORPERI = 'N'
                          AND PC.CDFILIAL     = @VCUR_FILIAL
                          AND PC.CDPRODUTO    = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          PRODUTO
                        WHERE @V_IDENTFORPERI  = 'N'
                          AND PC.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          PRODUTO
                        WHERE @V_IDENTFORPERI    = 'N'
                          AND PC.CDFILIAL        = @VCUR_FILIAL
                          AND ROT.CDSUBPRODLOC   = PRODUTO.CDPRODUTO
                          AND ROT.CDPRODUTO      = PC.CDPRODUTO
                          AND ROT.CDFILIAL       = PC.CDFILIAL
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSVMN,
                          PRODUTO
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          PREVCONSVMN.CDFILIALCLIE  = @VCUR_FILIAL   AND
                          PREVCONSVMN.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PREVCONSVMN.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PREVCONSVMN.DTPREVENDVMN BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          PC.QTPREVCONS * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONS PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          FI.CDFILIAL = FILIAL.CDFILIAL     AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                          FI.CDFILINECCMP = PC.CDFILIAL  AND
                          FI.IDSOLIPREV   = 'P'          AND
                          FI.CDFILIAL     = @VCUR_FILIAL   AND
                          PC.CDPRODUTO    = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PC.DTPREVCONS <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PC.DTPREVCONS BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          PC.QTPRODCOMP * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCOMPRA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          FI.CDFILIAL = FILIAL.CDFILIAL     AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                          FI.CDFILINECCMP  = PC.CDFILIAL  AND
                          FI.IDSOLIPREV    = 'P'          AND
                          FI.CDFILIAL      = @VCUR_FILIAL   AND
                          PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PC.DTPREVCOMP <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PC.DTPREVCOMP BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE @V_IDENTFORPERI = 'N'
                          AND FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND PC.CDPRODUTO     = PRODUTO.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)
                          AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC.CDPRODUTO)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          ROT.QTSUBPRODROT * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABRICA ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE @V_IDENTFORPERI = 'N'
                          AND FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDSUBPRODUTO = PRODUTO.CDPRODUTO
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)
                          AND NOT EXISTS (SELECT 1
                                          FROM ROTFABLOCAL
                                          WHERE ROTFABLOCAL.CDPRODUTO = PC.CDPRODUTO
                                            AND ROTFABLOCAL.CDFILIAL = PC.CDFILIAL)

                        UNION ALL

                        SELECT
                          ROT.QTSUBPRODLOC * PC.QTPRODCONPDVDIA * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSPDVDIA PC,
                          ROTFABLOCAL ROT,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE @V_IDENTFORPERI = 'N'
                          AND FI.CDFILIAL = FILIAL.CDFILIAL
                          AND ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'
                          AND FI.CDFILINECCMP  = PC.CDFILIAL
                          AND FI.IDSOLIPREV    = 'P'
                          AND FI.CDFILIAL      = @VCUR_FILIAL
                          AND ROT.CDSUBPRODLOC = PRODUTO.CDPRODUTO
                          AND ROT.CDFILIAL     = PC.CDFILIAL
                          AND ROT.CDPRODUTO    = PC.CDPRODUTO
                          AND PRODUTO.CDPRODESTO = @V_CDPRODUTO
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S')
                          AND (CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPRODCONPDV, 103), 103) BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          PC.QTSOLCONVMN * PRODUTO.VRFATOCONV AS QTPRODCONS
                        FROM
                          PREVCONSVMN PC,
                          FILINECE FI,
                          PRODUTO,
                          FILIAL
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          FI.CDFILIAL = FILIAL.CDFILIAL     AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                          FI.CDFILINECCMP  = PC.CDFILIALCLIE  AND
                          FI.IDSOLIPREV    = 'P'              AND
                          FI.CDFILIAL      = @VCUR_FILIAL       AND
                          PC.CDPRODUTO     = PRODUTO.CDPRODUTO AND
                          PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                          (PC.DTPREVENDVMN <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (PC.DTPREVENDVMN BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1)

                        UNION ALL

                        SELECT
                          IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
                        FROM
                          ITEMSOLI IT,
                          PRODUTO PR,
                          FILINECE FI,
                          FILIAL
                        WHERE
                          @V_IDENTFORPERI = 'N' AND
                          FI.CDFILIAL = FILIAL.CDFILIAL     AND
                          ISNULL(FILIAL.IDFILCENTPME, 'N') = 'N'         AND
                          FI.CDFILIAL     = @VCUR_FILIAL   AND
                          IT.CDPRODUTO    = PR.CDPRODUTO AND
                          PR.CDPRODESTO   = @V_CDPRODUTO AND
                          FI.CDFILINECCMP = IT.CDFILSOLI AND
                          FI.IDSOLIPREV  <> 'P'          AND
                          (IT.DTPROGENTR <> @V_DTPROCESS OR @V_RETIRDATA = 0 OR @V_IDESTOQUE <> 'S') AND
                          (IT.DTPROGENTR BETWEEN @V_DTPROCESS AND @V_DTENTREGA - 1) ) PREVCONGER;

                     IF @V_QTCONATEPREN IS NULL
                     BEGIN
                        SET @V_QTCONATEPREN = 0;
                     END;

                     IF @V_IDENTFORPERI = 'N' BEGIN
                        SET @V_DTPRIMENTREG = @V_DTENTREGA;
                     END;

                     IF ((@V_IDESTOQUE = 'S' AND @V_DTPRIMENTREG IS NOT NULL) OR
                         (@V_DTPRIMENTREG IS NULL) AND (@V_IDCSSOLAFFORAPERICMP = 'S'))
                     BEGIN
                        /* Se considera o estoque */
                        SET @V_DTAUX = @V_DTPROCESS + @V_QTDIAESTOQ;


                        IF @V_IDUTILLOTE = 'N' BEGIN
                           EXEC POSICAO_ESTOQUE @VCUR_FILIAL,
                                                @V_CDPRODUTO,
                                                @V_DTAUX,
                                                @P_QTDEESTO   = @V_QTESTONECCMP OUTPUT, /* Retorna o estoque */
                                                @P_VALRESTO   = @V_VALRESTO OUTPUT,
                                                @P_VALRBRUT   = @V_VALRBRUT OUTPUT,
                                                @P_POSNZERO   =  'N',
                                                @P_ALMOXARIFE = NULL,
                                                @P_LOCALESTOQ = NULL;
                        END
                        ELSE BEGIN
                           SELECT
                              @V_QTESTONECCMP = TEKNISA.CALC_ESTOQ_CONS(@VCUR_FILIAL, @V_CDPRODUTO, @V_DTAUX);
                        END;
                     END;
                     SET @V_QTESTOQATUAL = @V_QTESTONECCMP;

                     SELECT
                        @V_QTESTOSEGU = ISNULL(MAX(QTESTOSEGU), 0)
                     FROM
                        ESTOSEGU
                     WHERE
                        CDFILIAL   = @VCUR_FILIAL AND
                        CDPRODESTO = @V_CDPRODUTO;

                     IF (@V_IDSISDOS = '3') OR (@V_IDCONSAFNECCMP = 'S') BEGIN
                       SELECT /* "AF em Pendente" - Anterior  primeira entrega calculada, considerado no estoque inicial para abater o consumo at a primeira entrega+antecipado */
                         @V_QTESTAFPEND = ISNULL(SUM((QTPROGENTAF - ISNULL(QTEFETENTRAF,0)) * PRODUTO.VRFATOCONV), 0)
                       FROM
                         AUTOFORNE,
                         ITEMAUTF,
                         PRODUTO
                       WHERE
                         ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST  AND
                         ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC  AND
                         ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN AND
                         ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO    AND
                         ITEMAUTF.CDFILDEST  = @VCUR_FILIAL           AND
                         PRODUTO.CDPRODESTO  = @V_CDPRODUTO     AND
                         ITEMAUTF.DTPROGENTAF BETWEEN @V_DTPROCESS - 30 AND @V_DTENTREGA - 1 AND
                         (ITEMAUTF.IDBAIXITMAF IS NULL OR ITEMAUTF.IDBAIXITMAF = '1') AND
                         ITEMAUTF.QTPROGENTAF - ISNULL(ITEMAUTF.QTEFETENTRAF, 0) > 0     AND
                         AUTOFORNE.IDAFFORALIM = 'N'  AND
                         AUTOFORNE.IDSITUATUAAF IS NULL AND
                         ISNULL(AUTOFORNE.IDBAIXAAF, '0') NOT IN ('5','4','6');

                       SELECT /* "AF em Pendente" - Anterior  primeira entrega calculada, considerado no estoque inicial para abater o consumo at a primeira entrega+antecipado */
                         @V_QTESTAFPEXOL = ISNULL(SUM((QTPROGENPEOL - ISNULL(QTEFETENPEOL,0)) * PRODUTO.VRFATOCONV), 0)
                       FROM
                         PEDIDOEXOL,
                         ITEMPEDEXOL,
                         PRODUTO
                       WHERE
                         ITEMPEDEXOL.CDFILDEST = PEDIDOEXOL.CDFILDEST AND
                         ITEMPEDEXOL.CDFILLANC = PEDIDOEXOL.CDFILLANC AND
                         ITEMPEDEXOL.NRPEDEXOL = PEDIDOEXOL.NRPEDEXOL AND
                         ITEMPEDEXOL.CDPRODUTO = PRODUTO.CDPRODUTO AND
                         ITEMPEDEXOL.CDFILDEST = @VCUR_FILIAL AND
                         PRODUTO.CDPRODESTO = @V_CDPRODUTO AND
                         ITEMPEDEXOL.DTPROGENPEOL BETWEEN @V_DTPROCESS - 30 AND @V_DTENTREGA - 1 AND
                         (ITEMPEDEXOL.IDBAIXENPEOL IS NULL OR ITEMPEDEXOL.IDBAIXENPEOL = '1') AND
                         ITEMPEDEXOL.QTPROGENPEOL - ISNULL(ITEMPEDEXOL.QTEFETENPEOL, 0) > 0     AND
                         ISNULL(PEDIDOEXOL.IDBAIXEXOL, '0') NOT IN ('5','4') AND
                         ISNULL(ITEMPEDEXOL.IDITEMAJUSTE, 'N') = 'N';

                       SET @V_QTESTAFPEND = @V_QTESTAFPEND + @V_QTESTAFPEXOL;
                     END;

                     IF (@V_DTPRIMENTREG IS NOT NULL) BEGIN
                        SET @V_QTESTONECCMP = (@V_QTAFANTPRIENT + @V_QTESTONECCMP + @V_QTESTAFPEND + @V_QTESTAFPANT + @V_QTESTAFPDEP) - @V_QTCONATEPREN;
                        SET @V_IDPRIVEZPROD = 'N';
                     END;
                  END;

                  SET @V_QTESTNEGATIVIMPR = @V_QTESTONECCMP;

                  IF @V_QTESTONECCMP < 0
                  BEGIN
                     SET @V_QTESTONECCMP = 0;
                  END;

                  SET @V_IDESTNEGATIVO = 'N';

                  IF @V_DTENTREGA <> @V_DTPROCESS OR @V_ENTRADATA = 0 OR @V_IDESTOQUE <> 'S'
                  BEGIN
                     SET @V_QTESTONECCMP = @V_QTESTONECCMP + @V_QTJASOLICITA;
                  END;

                  IF (@V_DTENTREGA < @P_DTINICIAL) OR (@V_IDENTFORPERI = 'S') BEGIN
                     IF @V_IDESTNEGATIVO = 'N' BEGIN --Adriano na GR
                       IF (@V_QTESTONECCMP - @V_QTCONSANTECI) >= @V_QTASERENTREG BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTASERENTREG;
                       END
                       ELSE BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTESTONECCMP - @V_QTCONSANTECI;
                       END;
                     END
                     ELSE BEGIN
                       IF (@V_QTESTONECCMP) >= @V_QTASERENTREG BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTASERENTREG;
                       END
                       ELSE BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTESTONECCMP;
                       END;
                     END;
                  END
                  ELSE BEGIN
                     IF @V_IDESTNEGATIVO = 'N' BEGIN --Adriano na GR
                       IF (@V_QTESTONECCMP - @V_QTCONSANTECI - @V_QTESTOSEGU) >= @V_QTASERENTREG BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTASERENTREG;
                       END
                       ELSE BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTESTONECCMP - @V_QTCONSANTECI - @V_QTESTOSEGU;
                       END;
                     END
                     ELSE BEGIN
                       IF (@V_QTESTONECCMP - @V_QTESTOSEGU) >= @V_QTASERENTREG BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTASERENTREG;
                       END
                       ELSE BEGIN
                          SET @V_QTESTOUTILIZ = @V_QTESTONECCMP - @V_QTESTOSEGU;
                       END;
                     END;
                  END;

                  IF @V_IDCONSANTECPENDNECC = 'S' BEGIN
                     IF @V_IDESTOQUE = 'S' BEGIN
                        IF @V_QTESTOUTILIZ < 0
                        BEGIN
                           SET @V_QTESTOUTILIZ = 0;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     IF @V_QTESTOUTILIZ < 0 BEGIN
                        SET @V_QTESTOUTILIZ = 0;
                     END;
                  END;

                  SET @V_QTTEORNECCMP = @V_QTASERENTREG - @V_QTESTOUTILIZ;

                  IF @V_QTTEORNECCMP < 0
                  BEGIN
                     SET @V_QTORIGNECCMP = 0;
                  END
                  ELSE
                  BEGIN
                     SET @V_QTORIGNECCMP = @V_QTTEORNECCMP;
                  END;

                  IF (@V_IDENTFORPERI = 'N') AND (@V_DTENTREGA >= @P_DTINICIAL) BEGIN
                     IF @V_QTESTONECCMP < @V_QTESTOSEGU BEGIN
                        SET @V_QTORIGNECCMP = @V_QTORIGNECCMP + (@V_QTESTOSEGU - @V_QTESTONECCMP);
                     END;
                  END;

                  SET @V_APENAS_CONSUMO = 0;
                  SELECT
                     @V_APENAS_CONSUMO = COUNT(*)
                  FROM
                     PRODUTO,
                     PRODNECECOMP
                  WHERE
                     PRODUTO.CDPRODUTO     = PRODNECECOMP.CDPRODUTO AND
                     PRODNECECOMP.CDFILIAL = @VCUR_FILIAL           AND
                     @V_CDARVPROD LIKE PRODUTO.CDARVPROD+'%';
                  IF @V_APENAS_CONSUMO = 0 BEGIN
                     SET @V_QTPRACOMPRAR = CASE SUBSTRING(CAST(@V_QTORIGNECCMP AS VARCHAR), LEN(CAST(@V_QTORIGNECCMP AS VARCHAR))-1, 2)
                                              WHEN '00' THEN 0
                                              ELSE 0.001
                                           END
                                           + ROUND(@V_QTORIGNECCMP, 3, 1);
                  END
                  ELSE BEGIN
                     SET @V_QTPRACOMPRAR = CASE SUBSTRING(CAST(@V_QTASERENTREG AS VARCHAR), LEN(CAST(@V_QTASERENTREG AS VARCHAR))-1, 2)
                                              WHEN '00' THEN 0
                                              ELSE 0.001
                                           END
                                           + ROUND(@V_QTASERENTREG, 3, 1);
                  END;
                  /* Busca o cdigo do produto preferencial de um determinado produto de estoque */

                  SET @V_CDPRODPREF = NULL;
                  SELECT
                     @V_CDPRODPREF = MAX(PRODPREFMED.CDPRODPREF)
                  FROM
                     PRODPREFMED
                  WHERE
                     (PRODPREFMED.CDFILIAL  = @VCUR_FILIAL) AND
                     (PRODPREFMED.CDPRODUTO = @V_CDPRODUTO);

                  IF @V_CDPRODPREF IS NOT NULL BEGIN
                     SET @V_PRODFILI = 0;
                     SELECT
                        @V_PRODFILI = COUNT(*)
                     FROM
                        PRODFILI
                     WHERE
                        (@V_CDPRODPREF         = PRODFILI.CDPRODUTO) AND
                        (@VCUR_FILIAL          = PRODFILI.CDFILIAL)  AND
                        (ISNULL(PRODFILI.IDPRODATIV,'A') = 'A');
                     IF (NOT(@V_PRODFILI > 0)) BEGIN
                        SET @V_INAT = 0;
                        SELECT
                           @V_INAT = COUNT(*)
                        FROM
                           TRABNECEINAT
                        WHERE
                           NRNECCMPINAT = @P_NRNECECOMP   AND
                           CDFILNECINAT = @VCUR_FILIAL    AND
                           CDPRONECINAT = @V_CDPRODPREF;

                        IF (NOT(@V_INAT > 0)) BEGIN
                           INSERT INTO
                              TRABNECEINAT (NRNECCMPINAT, CDFILNECINAT, CDPRONECINAT)
                           VALUES
                              (@P_NRNECECOMP, @VCUR_FILIAL, @V_CDPRODPREF);
                           COMMIT;
                        END;
                        SET @V_CDPRODPREF = NULL;
                     END;
                  END;
                  IF (@@ROWCOUNT = 0) OR (@V_CDPRODPREF IS NULL) OR (ISNULL(@V_IDUTPRODPREF,'N') <> 'S')
                  BEGIN
                     /* Busca os valores de arredondamento e o fator de converso */

                     SET @V_VRARREDCMP = NULL;
                     SET @V_VRFATOCONV = NULL;
                     SELECT
                        @V_VRARREDCMP = CASE ISNULL(VRARREDCMP, 0)
                                           WHEN 0
                                           THEN 1
                                           ELSE ISNULL(VRARREDCMP, 0)
                                        END,
                        @V_VRFATOCONV = CASE ISNULL(VRFATOCONV, 0)
                                           WHEN 0
                                           THEN 1
                                           ELSE ISNULL(VRFATOCONV, 0)
                                        END
                     FROM
                        PRODUTO
                     WHERE
                        (CDPRODUTO = @V_CDPRODUTO);
                     IF @V_APENAS_CONSUMO = 0 BEGIN
                        IF ((@V_QTORIGNECCMP / @V_VRARREDCMP) = ROUND(@V_QTORIGNECCMP / @V_VRARREDCMP, 0)) AND @V_VRARREDCMP > 0
                        BEGIN
                           SET @V_QTPRACOMPRAR = CASE SUBSTRING(CAST(CEILING(@V_QTORIGNECCMP / @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR), LEN(CAST(CEILING(@V_QTORIGNECCMP * @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR))-1, 2)
                                                    WHEN '00' THEN 0
                                                    ELSE 0.001
                                                 END
                                                 + ROUND(CEILING(@V_QTORIGNECCMP / @V_VRARREDCMP) * @V_VRARREDCMP, 3, 1)
                        END;
                     END
                     ELSE BEGIN
                        IF ((@V_QTASERENTREG / @V_VRARREDCMP) = ROUND(@V_QTASERENTREG / @V_VRARREDCMP, 0)) AND @V_VRARREDCMP > 0
                        BEGIN
                           SET @V_QTPRACOMPRAR = CASE SUBSTRING(CAST(CEILING(@V_QTASERENTREG / @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR), LEN(CAST(CEILING(@V_QTASERENTREG * @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR))-1, 2)
                                                    WHEN '00' THEN 0
                                                    ELSE 0.001
                                                 END
                                                 + ROUND(CEILING(@V_QTASERENTREG / @V_VRARREDCMP) * @V_VRARREDCMP, 3, 1)
                        END;
                     END;
                     SET @V_QTPRCNVCOMPR = @V_QTPRACOMPRAR;
                  END
                  ELSE
                  BEGIN
                     /* Verifica se o produto poder ser convertido pelo parmetro da Filial */
                     SET @V_IDUTPRODPREF = NULL;
                     SELECT
                        @V_IDUTPRODPREF = IDUTPRODPREF
                     FROM
                        PARCMPSUP
                     WHERE
                        (CDFILIAL = @VCUR_FILIAL);

                     IF @V_IDUTPRODPREF = 'S'
                     BEGIN

                        /* Busca os valores de arredondamento e o fator de converso do produto preferencial */

                        SELECT
                           @V_VRARREDCMP = VRARREDCMP,
                           @V_VRFATOCONV = VRFATOCONV
                        FROM
                           PRODUTO
                        WHERE
                           (CDPRODUTO = @V_CDPRODPREF);
                        SET @V_CDPRODUTO = @V_CDPRODPREF;

                        IF @V_APENAS_CONSUMO = 0 BEGIN
                           SET @V_QTPRCNVCOMPR = CASE SUBSTRING(CAST((@V_QTORIGNECCMP / @V_VRFATOCONV) AS VARCHAR), LEN(CAST(CEILING(@V_QTORIGNECCMP / @V_VRFATOCONV) AS VARCHAR))-1, 2)
                                                    WHEN '00' THEN 0
                                                    ELSE 0.001
                                                 END
                                                 + ROUND((@V_QTORIGNECCMP / @V_VRFATOCONV), 3, 1)
                        END
                        ELSE BEGIN
                           SET @V_QTPRCNVCOMPR = CASE SUBSTRING(CAST((@V_QTASERENTREG / @V_VRFATOCONV) AS VARCHAR), LEN(CAST(CEILING(@V_QTASERENTREG / @V_VRFATOCONV) AS VARCHAR))-1, 2)
                                                    WHEN '00' THEN 0
                                                    ELSE 0.001
                                                 END
                                                 + ROUND((@V_QTASERENTREG / @V_VRFATOCONV), 3, 1)
                        END;
                        IF ((@V_QTPRCNVCOMPR / @V_VRARREDCMP) = ROUND(@V_QTPRCNVCOMPR / @V_VRARREDCMP, 0)) AND @V_VRARREDCMP > 0
                        BEGIN
                           SET @V_QTPRCNVCOMPR = CASE SUBSTRING(CAST(CEILING(@V_QTPRCNVCOMPR / @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR), LEN(CAST(CEILING(@V_QTPRCNVCOMPR * @V_VRARREDCMP) * @V_VRARREDCMP AS VARCHAR))-1, 2)
                                                    WHEN '00' THEN 0
                                                    ELSE 0.001
                                                 END
                                                 + ROUND(CEILING(@V_QTPRCNVCOMPR / @V_VRARREDCMP) * @V_VRARREDCMP, 3, 1)
                        END;
                        SET @V_QTPRACOMPRAR = @V_QTPRCNVCOMPR*@V_VRFATOCONV;
                     END;
                  END;

                  IF ROUND(@V_QTPRCNVCOMPR, 3) = 0 BEGIN
                     SET @V_QTPRCNVCOMPR = 0;
                  END;

                  IF ROUND(@V_QTPRACOMPRAR, 3) = 0 BEGIN
                     SET @V_QTPRACOMPRAR = 0;
                  END;

                  IF (@V_DTENTREGA < @P_DTINICIAL) OR (@V_IDENTFORPERI = 'S') BEGIN
                    SET @V_IDMARCNECCMP = 'N';
                  END
                  ELSE BEGIN
                    SELECT
                      @V_IDMARCNECCMP = MAX(CASE ISNULL(@V_QTPRCNVCOMPR, 0)
                                               WHEN 0 THEN 'N'
                                               ELSE 'S'
                                            END)
                    FROM
                      PARAMGERAL;
                  END;

                  SET @V_CDFILIOPELOG = NULL;
                  SELECT
                     @V_CDFILIOPELOG = MAX(P.CDFILIOPELOG)
                  FROM
                     PARAMPRODSUP P
                  WHERE P.CDFILIAL = @VCUR_FILIAL
                    AND P.CDPRODUTO = @V_CDPRODUTO
                    AND P.CDFILIOPELOG IS NOT NULL;
                  SET @V_DTENTREGA_1    = @V_DTENTREGA+@V_NRDIASEG;
                  SET @V_DTANTPROXENT_1 = @V_DTANTPROXENT+@V_NRDIASEGANT;
                  INSERT INTO TRABNECECOMP /* Insere dados na tabela de trabalho */
                     (CDFILNECECMP,
                      NRNECECOMP,
                      CDPRODNECCMP,
                      DTENTRNECCMP,
                      DTANENNECCMP,
                      QTCONATEPREN,
                      QTESTOQATUAL,
                      DTPRIUTIPROD,
                      QTASERENTREG,
                      QTCONSPERIOD,
                      QTCONSANTECI,
                      QTESTONECCMP,
                      QTESTOUTILIZ,
                      QTJASOLICITA,
                      QTTEORNECCMP,
                      QTORIGNECCMP,
                      QTPRACOMPRAR,
                      QTPRCNVCOMPR,
                      QTESTAFPEND,
                      QTESTAFPANT,
                      QTESTAFPDEP,
                      IDMARCNECCMP,
                      IDENTFORPERI,
                      DTPRIMENTREG,
                      QTESTNEGATIV,
                      NRDIASEGPROD,
                      QTESTOSEGCAD,
                      NRLIMISEGCAD,
                      CDFILIOPELOG,
                      QTJASOLICITAFP,
                      DTENTREGASEG,
                      DTANTPROXENTSEG,
                      QTSOLIPROD,
                      QTPROGENTAF,
                      IDPREVIACONSAF,
                      NRSEQCMPGER)
                   VALUES
                     (@VCUR_FILIAL,
                      @P_NRNECECOMP,
                      @V_CDPRODUTO,
                      @V_DTENTREGA,
                      @V_DTANTPROXENT,
                      @V_QTCONATEPREN,
                      @V_QTESTOQATUAL,
                      @V_DTPRIUTIPROD,
                      @V_QTASERENTREG,
                      @V_QTCONSPERIOD,
                      @V_QTCONSANTECI,
                      @V_QTESTONECCMP,
                      @V_QTESTOUTILIZ,
                      @V_QTJASOLICITA,
                      @V_QTTEORNECCMP,
                      @V_QTORIGNECCMP,
                      @V_QTPRACOMPRAR,
                      @V_QTPRCNVCOMPR,
                      @V_QTESTAFPEND,
                      @V_QTESTAFPANT,
                      @V_QTESTAFPDEP,
                      @V_IDMARCNECCMP,
                      @V_IDENTFORPERI,
                      @V_DTPRIMENTREG,
                      @V_QTESTNEGATIVIMPR,
                      @V_NRDIASEG,
                      @V_QTESTOSEGU,
                      @V_NRLIMISEGCAD,
                      @V_CDFILIOPELOG,
                      @V_QTJASOLICITADAFP,
                      @V_DTENTREGA_1,
                      @V_DTANTPROXENT_1,
                      @V_QTSOLIPROD,
                      @V_QTPROGENTAF,
                      @V_IDCONSAFNECCMP,
                      @V_NRSEQCMPGER);

                  IF (@V_IDEVOLESTONC = 'S') AND (@V_IDMARCNECCMP = 'N') BEGIN
                     IF @V_IDESTNEGATIVO = 'N' BEGIN
                        SET @V_QTESTONECCMP = @V_QTESTONECCMP - @V_QTCONSPERIOD;
                     END
                     ELSE BEGIN
                        SET @V_QTESTONECCMP = (@V_QTESTONECCMP + @V_QTESTNEGATIVCALC) - @V_QTCONSPERIOD;
                     END;
                  END
                  ELSE BEGIN
                     IF @V_IDESTNEGATIVO = 'N' BEGIN
                        SET @V_QTESTONECCMP = (@V_QTESTONECCMP + @V_QTPRACOMPRAR) - @V_QTCONSPERIOD;
                     END
                     ELSE BEGIN
                        SET @V_QTESTONECCMP = (@V_QTESTONECCMP + @V_QTESTNEGATIVCALC + @V_QTPRACOMPRAR) - @V_QTCONSPERIOD;
                     END;
                  END;
                  IF (@V_IDEVOLESTONC = 'S') BEGIN
                     IF @V_QTESTONECCMP < 0 BEGIN
                        SET @V_QTESTONECCMP = 0;
                     END;
                  END;

                  FETCH NEXT FROM C_PREV_DATA INTO @V_DTENTREGA, @V_DTANTPROXENT, @V_CDPERIENTR, @V_IDENTFORPERI;
               END;
               CLOSE C_PREV_DATA;
               DEALLOCATE C_PREV_DATA;
            END
            ELSE BEGIN
               SET @V_INAT = 0;
               SELECT
                  @V_INAT = COUNT(*)
               FROM
                  TRABNECEINAT
               WHERE
                  NRNECCMPINAT = @P_NRNECECOMP  AND
                  CDFILNECINAT = @VCUR_FILIAL   AND
                  CDPRONECINAT = @V_CDPRODUTO;
               IF (NOT(@V_INAT > 0)) BEGIN
                  INSERT INTO
                     TRABNECEINAT (NRNECCMPINAT, CDFILNECINAT, CDPRONECINAT)
                  VALUES
                     (@P_NRNECECOMP, @VCUR_FILIAL, @V_CDPRODUTO);
               END;
            END;
            FETCH NEXT FROM C_PREV INTO @V_CDPRODUTO, @V_CDARVPROD;
         END;
         CLOSE C_PREV;
         DEALLOCATE C_PREV;

         SET @V_DTINICIAL = @P_DTINICIAL;

         SET @V_CONTAUXI = 1;
         WHILE @V_CONTAUXI > 0 BEGIN
            SET @V_CONTAUXI = 0;
            SELECT
               @V_CONTAUXI = COUNT(*)
            FROM
               FERICOMP
            WHERE
               CDFILIAL = @VCUR_FILIAL AND
               DTFERICOMP = @V_DTINICIAL;
            IF @V_CONTAUXI > 0 BEGIN
               SET @V_DTINICIAL = @V_DTINICIAL - 1;
            END;
         END;

         /* INSERE OS DADOS REFERENTES AO MAPA DE DISTRIBUIO POR ALMOXARIFADO DO VND */
         IF @V_IDMAPDISTALMOX = 'S' BEGIN
            SET @V_DTAUX = @V_DTPROCESS + @V_QTDIAESTOQ;
            DECLARE C_PREVISAOVND CURSOR FOR
                SELECT
                   CDFILIAL,
                   CDLOJA,
                   CDPRODUTO,
                   CDALMOXARIFE,
                   CDLOCALESTOQ,
                   SUM(QTPREVCONS)
                FROM
                   (SELECT
                     PC_PDV.CDFILIAL,
                     PDV.CDLOJA,
                     P.CDPRODESTO AS CDPRODUTO,
                     LOJA.CDALMOXARIFE,
                     LOJA.CDLOCALESTOQ,
                     PC_PDV.QTPRODCONPDVDIA*P.VRFATOCONV AS QTPREVCONS
                    FROM PREVISAOPDV PDV, PREVCONSPDVDIA PC_PDV, PRODUTO P, LOJA
                    WHERE PC_PDV.CDPRODUTO = P.CDPRODUTO
                      AND PC_PDV.CDFILIAL = @VCUR_FILIAL
                      AND PC_PDV.CDFILIAL = PDV.CDFILIAL
                      AND PC_PDV.NRSEQPREVPDV = PDV.NRSEQPREVPDV
                      AND CONVERT(DATETIME, CONVERT(VARCHAR, PC_PDV.DTPRODCONPDV, 103), 103) BETWEEN CONVERT(DATETIME, CONVERT(VARCHAR, @V_DTPROCESS, 103), 103)
                                                                                               AND CONVERT(DATETIME, CONVERT(VARCHAR, @P_DTFINAL, 103), 103)
                      AND PC_PDV.CDPRODUTO = P.CDPRODUTO
                      AND P.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN
                      AND LOJA.CDFILIAL = @VCUR_FILIAL
                      AND LOJA.CDLOJA = PDV.CDLOJA
                      AND NOT EXISTS (SELECT 1 FROM ROTFABRICA WHERE ROTFABRICA.CDPRODUTO = PC_PDV.CDPRODUTO)
                      AND NOT EXISTS (SELECT 1
                                      FROM ROTFABLOCAL
                                      WHERE ROTFABLOCAL.CDPRODUTO = PC_PDV.CDPRODUTO
                                        AND ROTFABLOCAL.CDFILIAL = PC_PDV.CDFILIAL)
                    UNION ALL
                    SELECT
                     PC_PDV.CDFILIAL,
                     PDV.CDLOJA,
                     P.CDPRODESTO AS CDPRODUTO,
                     LOJA.CDALMOXARIFE,
                     LOJA.CDLOCALESTOQ,
                     ROT.QTSUBPRODROT*PC_PDV.QTPRODCONPDVDIA*P.VRFATOCONV AS QTPREVCONS
                    FROM PREVISAOPDV PDV, PREVCONSPDVDIA PC_PDV, ROTFABRICA ROT, PRODUTO P, LOJA
                    WHERE ROT.CDSUBPRODUTO = P.CDPRODUTO
                      AND ROT.CDPRODUTO    = PC_PDV.CDPRODUTO
                      AND PC_PDV.CDFILIAL  = @VCUR_FILIAL
                      AND PC_PDV.CDFILIAL  = PDV.CDFILIAL
                      AND PC_PDV.NRSEQPREVPDV = PDV.NRSEQPREVPDV
                      AND CONVERT(DATETIME, CONVERT(VARCHAR, PC_PDV.DTPRODCONPDV, 103), 103) BETWEEN CONVERT(DATETIME, CONVERT(VARCHAR, @V_DTPROCESS, 103), 103)
                                                                                               AND CONVERT(DATETIME, CONVERT(VARCHAR, @P_DTFINAL, 103), 103)
                      AND PC_PDV.CDPRODUTO = P.CDPRODUTO
                      AND P.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN
                      AND LOJA.CDFILIAL = @VCUR_FILIAL
                      AND LOJA.CDLOJA = PDV.CDLOJA
                      AND NOT EXISTS (SELECT 1
                                      FROM ROTFABLOCAL
                                      WHERE ROTFABLOCAL.CDPRODUTO = PC_PDV.CDPRODUTO
                                        AND ROTFABLOCAL.CDFILIAL = PC_PDV.CDFILIAL)

                    UNION ALL

                    SELECT
                     PC_PDV.CDFILIAL,
                     PDV.CDLOJA,
                     P.CDPRODESTO AS CDPRODUTO,
                     LOJA.CDALMOXARIFE,
                     LOJA.CDLOCALESTOQ,
                     ROT.QTSUBPRODLOC*PC_PDV.QTPRODCONPDVDIA*P.VRFATOCONV AS QTPREVCONS
                    FROM PREVISAOPDV PDV, PREVCONSPDVDIA PC_PDV, ROTFABLOCAL ROT, PRODUTO P, LOJA
                    WHERE ROT.CDSUBPRODLOC = P.CDPRODUTO
                      AND ROT.CDPRODUTO    = PC_PDV.CDPRODUTO
                      AND ROT.CDFILIAL     = PC_PDV.CDFILIAL
                      AND PC_PDV.CDFILIAL  = @VCUR_FILIAL
                      AND PC_PDV.CDFILIAL  = PDV.CDFILIAL
                      AND PC_PDV.NRSEQPREVPDV = PDV.NRSEQPREVPDV
                      AND CONVERT(DATETIME, CONVERT(VARCHAR, PC_PDV.DTPRODCONPDV, 103), 103) BETWEEN CONVERT(DATETIME, CONVERT(VARCHAR, @V_DTPROCESS, 103), 103)
                                                                                               AND CONVERT(DATETIME, CONVERT(VARCHAR, @P_DTFINAL, 103), 103)
                      AND PC_PDV.CDPRODUTO = P.CDPRODUTO
                      AND P.CDARVPROD BETWEEN @V_CDPRODINI AND @V_CDPRODFIN
                      AND LOJA.CDFILIAL = @VCUR_FILIAL
                      AND LOJA.CDLOJA = PDV.CDLOJA) SUB
                   GROUP BY
                     CDFILIAL,
                     CDLOJA,
                     CDPRODUTO,
                     CDALMOXARIFE,
                     CDLOCALESTOQ
            OPEN C_PREVISAOVND;
            FETCH NEXT FROM C_PREVISAOVND INTO @V_PREVISAOVND_CDFILIAL,
                                               @V_PREVISAOVND_CDLOJA,
                                               @V_PREVISAOVND_CDPRODUTO,
                                               @V_PREVISAOVND_CDALMOXARIFE,
                                               @V_PREVISAOVND_CDLOCALESTOQ,
                                               @V_PREVISAOVND_QTPREVCONS;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               SET @V_QTESTOQUEVND = 0;
               IF @V_PREVISAOVND_CDALMOXARIFE IS NOT NULL BEGIN
                  EXEC POSICAO_ESTOQUE @VCUR_FILIAL,
                                       @V_PREVISAOVND_CDPRODUTO,
                                       @V_DTAUX,
                                       @P_QTDEESTO   = @V_QTESTOQUEVND OUTPUT, /* Retorna o estoque */
                                       @P_VALRESTO   = @V_VALRESTO     OUTPUT,
                                       @P_VALRBRUT   = @V_VALRBRUT     OUTPUT,
                                       @P_POSNZERO   = 'N',
                                       @P_ALMOXARIFE = @V_PREVISAOVND_CDALMOXARIFE,
                                       @P_LOCALESTOQ = @V_PREVISAOVND_CDLOCALESTOQ;
               END
               ELSE BEGIN
                  IF @V_IDUTILLOTE = 'N' BEGIN
                     EXEC POSICAO_ESTOQUE @VCUR_FILIAL,
                                          @V_CDPRODUTO,
                                          @V_DTAUX,
                                          @P_QTDEESTO   = @V_QTESTONECCMP OUTPUT, /* Retorna o estoque */
                                          @P_VALRESTO   = @V_VALRESTO OUTPUT,
                                          @P_VALRBRUT   = @V_VALRBRUT OUTPUT,
                                          @P_POSNZERO   =  'N',
                                          @P_ALMOXARIFE = NULL,
                                          @P_LOCALESTOQ = NULL;
                  END
                  ELSE BEGIN
                     SELECT
                        @V_QTESTONECCMP = TEKNISA.CALC_ESTOQ_CONS(@VCUR_FILIAL, @V_CDPRODUTO, @V_DTAUX);
                  END;
               END;
               INSERT INTO MAPDISTALMOX (CDFILIAL, NRNECECMPMAP, CDLOJA,
                                         CDPRODUTO, DTINIMAPDIST, DTFINMAPDIST,
                                         QTPREVCONLOJ, QTESTOQUELOJ)
               VALUES(@VCUR_FILIAL, @P_NRNECECOMP, @V_PREVISAOVND_CDLOJA,
                      @V_PREVISAOVND_CDPRODUTO, @P_DTINICIAL, @P_DTFINAL,
                      @V_PREVISAOVND_QTPREVCONS, @V_QTESTOQUEVND);

               FETCH NEXT FROM C_PREVISAOVND INTO @V_PREVISAOVND_CDFILIAL,
                                                  @V_PREVISAOVND_CDLOJA,
                                                  @V_PREVISAOVND_CDPRODUTO,
                                                  @V_PREVISAOVND_CDALMOXARIFE,
                                                  @V_PREVISAOVND_CDLOCALESTOQ,
                                                  @V_PREVISAOVND_QTPREVCONS;
            END;
         END;

         DECLARE C_DELTRAB CURSOR FOR
           SELECT
             NRNECECOMP,
             CDPRODNECCMP,
             DTENTRNECCMP
           FROM
             TRABNECECOMP
           WHERE
            (NRNECECOMP = @P_NRNECECOMP) AND
            (CDFILNECECMP = @VCUR_FILIAL) AND
            ((QTPRACOMPRAR IS NULL OR QTPRACOMPRAR = 0) AND @V_IDQTDEZERO = 'N')
         OPEN C_DELTRAB;
         FETCH NEXT FROM C_DELTRAB INTO @V_DELTRAB_NRNECECOMP,
                                        @V_DELTRAB_CDPRODNECCMP,
                                        @V_DELTRAB_DTENTRNECCMP;

         WHILE (@@FETCH_STATUS = 0) BEGIN
           DELETE FROM TRABNECECOMP
           WHERE
             NRNECECOMP   = @V_DELTRAB_NRNECECOMP   AND
             CDPRODNECCMP = @V_DELTRAB_CDPRODNECCMP AND
             DTENTRNECCMP = @V_DELTRAB_DTENTRNECCMP;

           FETCH NEXT FROM C_DELTRAB INTO @V_DELTRAB_NRNECECOMP,
                                          @V_DELTRAB_CDPRODNECCMP,
                                          @V_DELTRAB_DTENTRNECCMP;

         END;
         CLOSE C_DELTRAB;
         DEALLOCATE C_DELTRAB;

         INSERT INTO LOGNECECOMP /* Insere os dados do clculo na tabela de log */
            (CDFILIAL,
             CDOPERADOR,
             DTHRCALCNC,
             DTINICIALNC,
             DTFINALNC,
             CDPRODINICNC,
             CDPRODFINANC,
             IDUTILESTONC,
             PEACRESCIMNC,
             NRNECECMPLOG,
             IDGERSOLEXTNCMP)
         VALUES
            (@VCUR_FILIAL,
             @P_CDOPERADOR,
             @P_DTHRCALCNC,
             @P_DTINICIAL,
             @P_DTFINAL,
             @P_CDPRODINI,
             @P_CDPRODFIN,
             @V_IDESTOQUE,
             @P_PEACRESCIMO,
             @P_NRNECECOMP,
             @V_EXTRA);
      END;
      FETCH NEXT FROM CUR_FILIAL INTO @VCUR_FILIAL;
   END;
   CLOSE CUR_FILIAL;
   DEALLOCATE CUR_FILIAL;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'NECESSIDADE_DE_COMPRAS','6.35.028';
GO
